class _FieldInfo:
 """ Exposes the public members of the System.Reflection.FieldInfo class to unmanaged code. """
 def Equals(self,other):
  """
  Equals(self: _FieldInfo,other: object) -> bool

  

   Provides COM objects with version-independent access to the System.Object.Equals(System.Object) 

    method.

  

  

   other: The System.Object to compare with the current System.Object.

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def GetCustomAttributes(self,*__args):
  """
  GetCustomAttributes(self: _FieldInfo,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.GetCustomAttributes(System.Boolean) method.

  

  

   inherit: Specifies whether to search this member's inheritance chain to find the attributes.

   Returns: An array that contains all the custom attributes,or an array with zero elements if no 

    attributes are defined.

  

  GetCustomAttributes(self: _FieldInfo,attributeType: Type,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.GetCustomAttributes(System.Type,System.Boolean) method.

  

  

   attributeType: The type of attribute to search for. Only attributes that are assignable to this type are 

    returned.

  

   inherit: Specifies whether to search this member's inheritance chain to find the attributes.

   Returns: An array of custom attributes applied to this member,or an array with zero (0) elements if no 

    attributes have been applied.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: _FieldInfo) -> int

  

   Provides COM objects with version-independent access to the System.Object.GetHashCode method.

   Returns: The hash code for the current instance.
  """
  pass
 def GetIDsOfNames(self,riid,rgszNames,cNames,lcid,rgDispId):
  """
  GetIDsOfNames(self: _FieldInfo,riid: Guid,rgszNames: IntPtr,cNames: UInt32,lcid: UInt32,rgDispId: IntPtr) -> Guid

  

   Maps a set of names to a corresponding set of dispatch identifiers.

  

   riid: Reserved for future use. Must be IID_NULL.

   rgszNames: Passed-in array of names to be mapped.

   cNames: Count of the names to be mapped.

   lcid: The locale context in which to interpret the names.

   rgDispId: Caller-allocated array that receives the IDs corresponding to the names.
  """
  pass
 def GetType(self):
  """
  GetType(self: _FieldInfo) -> Type

  

   Provides COM objects with version-independent access to the System.Object.GetType method.

   Returns: A System.Type object.
  """
  pass
 def GetTypeInfo(self,iTInfo,lcid,ppTInfo):
  """
  GetTypeInfo(self: _FieldInfo,iTInfo: UInt32,lcid: UInt32,ppTInfo: IntPtr)

   Retrieves the type information for an object,which can then be used to get the type information 

    for an interface.

  

  

   iTInfo: The type information to return.

   lcid: The locale identifier for the type information.

   ppTInfo: Receives a pointer to the requested type information object.
  """
  pass
 def GetTypeInfoCount(self,pcTInfo):
  """
  GetTypeInfoCount(self: _FieldInfo) -> UInt32

  

   Retrieves the number of type information interfaces that an object provides (either 0 or 1).
  """
  pass
 def GetValue(self,obj):
  """
  GetValue(self: _FieldInfo,obj: object) -> object

  

   Provides COM objects with version-independent access to the 

    System.Reflection.FieldInfo.GetValue(System.Object) method.

  

  

   obj: The object whose field value will be returned.

   Returns: An object containing the value of the field reflected by this instance.
  """
  pass
 def GetValueDirect(self,obj):
  """
  GetValueDirect(self: _FieldInfo,obj: TypedReference) -> object

  

   Provides COM objects with version-independent access to the 

    System.Reflection.FieldInfo.GetValueDirect(System.TypedReference) method.

  

  

   obj: A System.TypedReference structure that encapsulates a managed pointer to a location and a 

    runtime representation of the type that might be stored at that location.

  

   Returns: An System.Object containing a field value.
  """
  pass
 def Invoke(self,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr):
  """
  Invoke(self: _FieldInfo,dispIdMember: UInt32,riid: Guid,lcid: UInt32,wFlags: Int16,pDispParams: IntPtr,pVarResult: IntPtr,pExcepInfo: IntPtr,puArgErr: IntPtr) -> Guid

  

   Provides access to properties and methods exposed by an object.

  

   dispIdMember: Identifies the member.

   riid: Reserved for future use. Must be IID_NULL.

   lcid: The locale context in which to interpret arguments.

   wFlags: Flags describing the context of the call.

   pDispParams: Pointer to a structure containing an array of arguments,an array of argument DISPIDs for named 

    arguments,and counts for the number of elements in the arrays.

  

   pVarResult: Pointer to the location where the result is to be stored.

   pExcepInfo: Pointer to a structure that contains exception information.

   puArgErr: The index of the first argument that has an error.
  """
  pass
 def IsDefined(self,attributeType,inherit):
  """
  IsDefined(self: _FieldInfo,attributeType: Type,inherit: bool) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.IsDefined(System.Type,System.Boolean) method.

  

  

   attributeType: The System.Type object to which the custom attributes are applied.

   inherit: Specifies whether to search this member's inheritance chain to find the attributes.

   Returns: true if one or more instance of attributeType is applied to this member; otherwise,false.
  """
  pass
 def SetValue(self,obj,value,invokeAttr=None,binder=None,culture=None):
  """
  SetValue(self: _FieldInfo,obj: object,value: object)

   Provides COM objects with version-independent access to the 

    System.Reflection.FieldInfo.SetValue(System.Object,System.Object) method.

  

  

   obj: The object whose field value will be set.

   value: The value to assign to the field.

  SetValue(self: _FieldInfo,obj: object,value: object,invokeAttr: BindingFlags,binder: Binder,culture: CultureInfo)

   Provides COM objects with version-independent access to the 

    System.Reflection.PropertyInfo.SetValue(System.Object,System.Object,System.Reflection.BindingFlag

    s,System.Reflection.Binder,System.Object[],System.Globalization.CultureInfo) method.

  

  

   obj: The object whose field value will be set.

   value: The value to assign to the field.

   invokeAttr: A field of System.Reflection.Binder that specifies the type of binding that is desired (for 

    example,Binder.CreateInstance or Binder.ExactBinding).

  

   binder: A set of properties that enables the binding,coercion of argument types,and invocation of 

    members through reflection. If binder is null,then Binder.DefaultBinding is used.

  

   culture: The software preferences of a particular culture.
  """
  pass
 def SetValueDirect(self,obj,value):
  """
  SetValueDirect(self: _FieldInfo,obj: TypedReference,value: object)

   Provides COM objects with version-independent access to the 

    System.Reflection.FieldInfo.SetValueDirect(System.TypedReference,System.Object) method.

  

  

   obj: The object whose field value will be set.

   value: The value to assign to the field.
  """
  pass
 def ToString(self):
  """
  ToString(self: _FieldInfo) -> str

  

   Provides COM objects with version-independent access to the System.Object.ToString method.

   Returns: A string that represents the current System.Object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 Attributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.Attributes property.



Get: Attributes(self: _FieldInfo) -> FieldAttributes



"""

 DeclaringType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.DeclaringType property.



Get: DeclaringType(self: _FieldInfo) -> Type



"""

 FieldHandle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.FieldHandle property.



Get: FieldHandle(self: _FieldInfo) -> RuntimeFieldHandle



"""

 FieldType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.FieldType property.



Get: FieldType(self: _FieldInfo) -> Type



"""

 IsAssembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsAssembly property.



Get: IsAssembly(self: _FieldInfo) -> bool



"""

 IsFamily=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsFamily property.



Get: IsFamily(self: _FieldInfo) -> bool



"""

 IsFamilyAndAssembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsFamilyAndAssembly property.



Get: IsFamilyAndAssembly(self: _FieldInfo) -> bool



"""

 IsFamilyOrAssembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsFamilyOrAssembly property.



Get: IsFamilyOrAssembly(self: _FieldInfo) -> bool



"""

 IsInitOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsInitOnly property.



Get: IsInitOnly(self: _FieldInfo) -> bool



"""

 IsLiteral=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsLiteral property.



Get: IsLiteral(self: _FieldInfo) -> bool



"""

 IsNotSerialized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsNotSerialized property.



Get: IsNotSerialized(self: _FieldInfo) -> bool



"""

 IsPinvokeImpl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsPinvokeImpl property.



Get: IsPinvokeImpl(self: _FieldInfo) -> bool



"""

 IsPrivate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsPrivate property.



Get: IsPrivate(self: _FieldInfo) -> bool



"""

 IsPublic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsPublic property.



Get: IsPublic(self: _FieldInfo) -> bool



"""

 IsSpecialName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsSpecialName property.



Get: IsSpecialName(self: _FieldInfo) -> bool



"""

 IsStatic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.IsStatic property.



Get: IsStatic(self: _FieldInfo) -> bool



"""

 MemberType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.FieldInfo.MemberType property.



Get: MemberType(self: _FieldInfo) -> MemberTypes



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.Name property.



Get: Name(self: _FieldInfo) -> str



"""

 ReflectedType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.ReflectedType property.



Get: ReflectedType(self: _FieldInfo) -> Type



"""





class CryptoKeyAccessRule(AccessRule):
 """
 Represents an access rule for a cryptographic key. An access rule represents a combination of a user's identity,an access mask,and an access control type (allow or deny). An access rule object also contains information about the how the rule is inherited by child objects and how that inheritance is propagated.

 

 CryptoKeyAccessRule(identity: IdentityReference,cryptoKeyRights: CryptoKeyRights,type: AccessControlType)

 CryptoKeyAccessRule(identity: str,cryptoKeyRights: CryptoKeyRights,type: AccessControlType)
 """
 @staticmethod
 def __new__(self,identity,cryptoKeyRights,type):
  """
  __new__(cls: type,identity: IdentityReference,cryptoKeyRights: CryptoKeyRights,type: AccessControlType)

  __new__(cls: type,identity: str,cryptoKeyRights: CryptoKeyRights,type: AccessControlType)
  """
  pass
 AccessMask=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the access mask for this rule.



"""

 CryptoKeyRights=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cryptographic key operation to which this access rule controls access.



Get: CryptoKeyRights(self: CryptoKeyAccessRule) -> CryptoKeyRights



"""





class ToolStripPanelRow(Component,IComponent,IDisposable,IArrangedElement):
 """
 Represents a row of a System.Windows.Forms.ToolStripPanel that can contain controls.

 

 ToolStripPanelRow(parent: ToolStripPanel)
 """
 def CanMove(self,toolStripToDrag):
  """
  CanMove(self: ToolStripPanelRow,toolStripToDrag: ToolStrip) -> bool

  

   Gets or sets a value indicating whether a System.Windows.Forms.ToolStrip can be dragged and 

    dropped into a System.Windows.Forms.ToolStripPanelRow.

  

  

   toolStripToDrag: The System.Windows.Forms.ToolStrip to be dragged and dropped into the 

    System.Windows.Forms.ToolStripPanelRow.

  

   Returns: true if there is enough space in the System.Windows.Forms.ToolStripPanelRow to receive the 

    System.Windows.Forms.ToolStrip; otherwise,false.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ToolStripPanelRow,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.ToolStripPanelRow and 

    optionally releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnBoundsChanged(self,*args):
  """
  OnBoundsChanged(self: ToolStripPanelRow,oldBounds: Rectangle,newBounds: Rectangle)

   Occurs when the System.Windows.Forms.ToolStripPanelRow.Bounds property changes.

  

   oldBounds: The original value of the System.Windows.Forms.ToolStripPanelRow.Bounds property.

   newBounds: The new value of the System.Windows.Forms.ToolStripPanelRow.Bounds property.
  """
  pass
 def OnControlAdded(self,*args):
  """
  OnControlAdded(self: ToolStripPanelRow,control: Control,index: int)

   Raises the System.Windows.Forms.Control.ControlAdded event.

  

   control: The control that was added to the System.Windows.Forms.ToolStripPanelRow.

   index: The zero-based index representing the position of the added control.
  """
  pass
 def OnControlRemoved(self,*args):
  """
  OnControlRemoved(self: ToolStripPanelRow,control: Control,index: int)

   Raises the System.Windows.Forms.Control.ControlRemoved event.

  

   control: The control that was removed from the System.Windows.Forms.ToolStripPanelRow.

   index: The zero-based index representing the position of the removed control.
  """
  pass
 def OnLayout(self,*args):
  """
  OnLayout(self: ToolStripPanelRow,e: LayoutEventArgs)

   Raises the System.Windows.Forms.Control.Layout event.

  

   e: A System.Windows.Forms.LayoutEventArgs that contains the event data.
  """
  pass
 def OnOrientationChanged(self,*args):
  """
  OnOrientationChanged(self: ToolStripPanelRow)

   Occurs when the value of the System.Windows.Forms.ToolStripPanelRow.Orientation property changes.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,parent):
  """ __new__(cls: type,parent: ToolStripPanel) """
  pass
 def __str__(self,*args):
  pass
 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the System.Windows.Forms.ToolStripPanelRow,including its nonclient elements,in pixels,relative to the parent control.



Get: Bounds(self: ToolStripPanelRow) -> Rectangle



"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 Controls=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the controls in the System.Windows.Forms.ToolStripPanelRow.



Get: Controls(self: ToolStripPanelRow) -> Array[Control]



"""

 DefaultMargin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the space,in pixels,that is specified by default between controls.



"""

 DefaultPadding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the internal spacing,in pixels,of the contents of a control.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 DisplayRectangle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the display area of the control.



Get: DisplayRectangle(self: ToolStripPanelRow) -> Rectangle



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 LayoutEngine=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an instance of the control's layout engine.



Get: LayoutEngine(self: ToolStripPanelRow) -> LayoutEngine



"""

 Margin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the space between controls.



Get: Margin(self: ToolStripPanelRow) -> Padding



Set: Margin(self: ToolStripPanelRow)=value

"""

 Orientation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the layout direction of the System.Windows.Forms.ToolStripPanelRow relative to its containing System.Windows.Forms.ToolStripPanel.



Get: Orientation(self: ToolStripPanelRow) -> Orientation



"""

 Padding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets padding within the control.



Get: Padding(self: ToolStripPanelRow) -> Padding



Set: Padding(self: ToolStripPanelRow)=value

"""

 ToolStripPanel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.ToolStripPanel that contains the System.Windows.Forms.ToolStripPanelRow.



Get: ToolStripPanel(self: ToolStripPanelRow) -> ToolStripPanel



"""





class EditorAttribute(Attribute,_Attribute):
 """
 Specifies the editor to use to change a property. This class cannot be inherited.

 

 EditorAttribute()

 EditorAttribute(typeName: str,baseTypeName: str)

 EditorAttribute(typeName: str,baseType: Type)

 EditorAttribute(type: Type,baseType: Type)
 """
 def Equals(self,obj):
  """
  Equals(self: EditorAttribute,obj: object) -> bool

  

   Returns whether the value of the given object is equal to the current 

    System.ComponentModel.EditorAttribute.

  

  

   obj: The object to test the value equality of.

   Returns: true if the value of the given object is equal to that of the current object; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: EditorAttribute) -> int """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,typeName: str,baseTypeName: str)

  __new__(cls: type,typeName: str,baseType: Type)

  __new__(cls: type,type: Type,baseType: Type)
  """
  pass
 def __ne__(self,*args):
  pass
 EditorBaseTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the base class or interface serving as a lookup key for this editor.



Get: EditorBaseTypeName(self: EditorAttribute) -> str



"""

 EditorTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the editor class in the System.Type.AssemblyQualifiedName format.



Get: EditorTypeName(self: EditorAttribute) -> str



"""

 TypeId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a unique ID for this attribute type.



Get: TypeId(self: EditorAttribute) -> object



"""





class TreeNode(MarshalByRefObject,ICloneable,ISerializable):
 """
 Represents a node of a System.Windows.Forms.TreeView.

 

 TreeNode()

 TreeNode(text: str)

 TreeNode(text: str,children: Array[TreeNode])

 TreeNode(text: str,imageIndex: int,selectedImageIndex: int)

 TreeNode(text: str,imageIndex: int,selectedImageIndex: int,children: Array[TreeNode])
 """
 def BeginEdit(self):
  """
  BeginEdit(self: TreeNode)

   Initiates the editing of the tree node label.
  """
  pass
 def Clone(self):
  """
  Clone(self: TreeNode) -> object

  

   Copies the tree node and the entire subtree rooted at this tree node.

   Returns: The System.Object that represents the cloned System.Windows.Forms.TreeNode.
  """
  pass
 def Collapse(self,ignoreChildren=None):
  """
  Collapse(self: TreeNode)

   Collapses the tree node.

  Collapse(self: TreeNode,ignoreChildren: bool)

   Collapses the System.Windows.Forms.TreeNode and optionally collapses its children.

  

   ignoreChildren: true to leave the child nodes in their current state; false to collapse the child nodes.
  """
  pass
 def Deserialize(self,*args):
  """
  Deserialize(self: TreeNode,serializationInfo: SerializationInfo,context: StreamingContext)

   Loads the state of the System.Windows.Forms.TreeNode from the specified 

    System.Runtime.Serialization.SerializationInfo.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo that describes the 

    System.Windows.Forms.TreeNode.

  

   context: The System.Runtime.Serialization.StreamingContext that indicates the state of the stream during 

    deserialization.
  """
  pass
 def EndEdit(self,cancel):
  """
  EndEdit(self: TreeNode,cancel: bool)

   Ends the editing of the tree node label.

  

   cancel: true if the editing of the tree node label text was canceled without being saved; otherwise,

    false.
  """
  pass
 def EnsureVisible(self):
  """
  EnsureVisible(self: TreeNode)

   Ensures that the tree node is visible,expanding tree nodes and scrolling the tree view control 

    as necessary.
  """
  pass
 def Expand(self):
  """
  Expand(self: TreeNode)

   Expands the tree node.
  """
  pass
 def ExpandAll(self):
  """
  ExpandAll(self: TreeNode)

   Expands all the child tree nodes.
  """
  pass
 @staticmethod
 def FromHandle(tree,handle):
  """
  FromHandle(tree: TreeView,handle: IntPtr) -> TreeNode

  

   Returns the tree node with the specified handle and assigned to the specified tree view control.

  

   tree: The System.Windows.Forms.TreeView that contains the tree node.

   handle: The handle of the tree node.

   Returns: A System.Windows.Forms.TreeNode that represents the tree node assigned to the specified 

    System.Windows.Forms.TreeView control with the specified handle.
  """
  pass
 def GetNodeCount(self,includeSubTrees):
  """
  GetNodeCount(self: TreeNode,includeSubTrees: bool) -> int

  

   Returns the number of child tree nodes.

  

   includeSubTrees: true if the resulting count includes all tree nodes indirectly rooted at this tree node; 

    otherwise,false.

  

   Returns: The number of child tree nodes assigned to the System.Windows.Forms.TreeNode.Nodes collection.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def Remove(self):
  """
  Remove(self: TreeNode)

   Removes the current tree node from the tree view control.
  """
  pass
 def Serialize(self,*args):
  """
  Serialize(self: TreeNode,si: SerializationInfo,context: StreamingContext)

   Saves the state of the System.Windows.Forms.TreeNode to the specified 

    System.Runtime.Serialization.SerializationInfo.

  

  

   si: The System.Runtime.Serialization.SerializationInfo that describes the 

    System.Windows.Forms.TreeNode.

  

   context: The System.Runtime.Serialization.StreamingContext that indicates the state of the stream during 

    serialization
  """
  pass
 def Toggle(self):
  """
  Toggle(self: TreeNode)

   Toggles the tree node to either the expanded or collapsed state.
  """
  pass
 def ToString(self):
  """
  ToString(self: TreeNode) -> str

   Returns: A string that represents the current object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,text=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,text: str)

  __new__(cls: type,text: str,children: Array[TreeNode])

  __new__(cls: type,text: str,imageIndex: int,selectedImageIndex: int)

  __new__(cls: type,text: str,imageIndex: int,selectedImageIndex: int,children: Array[TreeNode])

  __new__(cls: type,serializationInfo: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color of the tree node.



Get: BackColor(self: TreeNode) -> Color



Set: BackColor(self: TreeNode)=value

"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bounds of the tree node.



Get: Bounds(self: TreeNode) -> Rectangle



"""

 Checked=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the tree node is in a checked state.



Get: Checked(self: TreeNode) -> bool



Set: Checked(self: TreeNode)=value

"""

 ContextMenu=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the shortcut menu that is associated with this tree node.



Get: ContextMenu(self: TreeNode) -> ContextMenu



Set: ContextMenu(self: TreeNode)=value

"""

 ContextMenuStrip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu associated with this tree node.



Get: ContextMenuStrip(self: TreeNode) -> ContextMenuStrip



Set: ContextMenuStrip(self: TreeNode)=value

"""

 FirstNode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the first child tree node in the tree node collection.



Get: FirstNode(self: TreeNode) -> TreeNode



"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color of the tree node.



Get: ForeColor(self: TreeNode) -> Color



Set: ForeColor(self: TreeNode)=value

"""

 FullPath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the path from the root tree node to the current tree node.



Get: FullPath(self: TreeNode) -> str



"""

 Handle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the handle of the tree node.



Get: Handle(self: TreeNode) -> IntPtr



"""

 ImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the image list index value of the image displayed when the tree node is in the unselected state.



Get: ImageIndex(self: TreeNode) -> int



Set: ImageIndex(self: TreeNode)=value

"""

 ImageKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the key for the image associated with this tree node when the node is in an unselected state.



Get: ImageKey(self: TreeNode) -> str



Set: ImageKey(self: TreeNode)=value

"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the position of the tree node in the tree node collection.



Get: Index(self: TreeNode) -> int



"""

 IsEditing=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the tree node is in an editable state.



Get: IsEditing(self: TreeNode) -> bool



"""

 IsExpanded=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the tree node is in the expanded state.



Get: IsExpanded(self: TreeNode) -> bool



"""

 IsSelected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the tree node is in the selected state.



Get: IsSelected(self: TreeNode) -> bool



"""

 IsVisible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the tree node is visible or partially visible.



Get: IsVisible(self: TreeNode) -> bool



"""

 LastNode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the last child tree node.



Get: LastNode(self: TreeNode) -> TreeNode



"""

 Level=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the zero-based depth of the tree node in the System.Windows.Forms.TreeView control.



Get: Level(self: TreeNode) -> int



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the tree node.



Get: Name(self: TreeNode) -> str



Set: Name(self: TreeNode)=value

"""

 NextNode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the next sibling tree node.



Get: NextNode(self: TreeNode) -> TreeNode



"""

 NextVisibleNode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the next visible tree node.



Get: NextVisibleNode(self: TreeNode) -> TreeNode



"""

 NodeFont=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font that is used to display the text on the tree node label.



Get: NodeFont(self: TreeNode) -> Font



Set: NodeFont(self: TreeNode)=value

"""

 Nodes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of System.Windows.Forms.TreeNode objects assigned to the current tree node.



Get: Nodes(self: TreeNode) -> TreeNodeCollection



"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the parent tree node of the current tree node.



Get: Parent(self: TreeNode) -> TreeNode



"""

 PrevNode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous sibling tree node.



Get: PrevNode(self: TreeNode) -> TreeNode



"""

 PrevVisibleNode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous visible tree node.



Get: PrevVisibleNode(self: TreeNode) -> TreeNode



"""

 SelectedImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the image list index value of the image that is displayed when the tree node is in the selected state.



Get: SelectedImageIndex(self: TreeNode) -> int



Set: SelectedImageIndex(self: TreeNode)=value

"""

 SelectedImageKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the key of the image displayed in the tree node when it is in a selected state.



Get: SelectedImageKey(self: TreeNode) -> str



Set: SelectedImageKey(self: TreeNode)=value

"""

 StateImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index of the image that is used to indicate the state of the System.Windows.Forms.TreeNode when the parent System.Windows.Forms.TreeView has its System.Windows.Forms.TreeView.CheckBoxes property set to false.



Get: StateImageIndex(self: TreeNode) -> int



Set: StateImageIndex(self: TreeNode)=value

"""

 StateImageKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the key of the image that is used to indicate the state of the System.Windows.Forms.TreeNode when the parent System.Windows.Forms.TreeView has its System.Windows.Forms.TreeView.CheckBoxes property set to false.



Get: StateImageKey(self: TreeNode) -> str



Set: StateImageKey(self: TreeNode)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains data about the tree node.



Get: Tag(self: TreeNode) -> object



Set: Tag(self: TreeNode)=value

"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text displayed in the label of the tree node.



Get: Text(self: TreeNode) -> str



Set: Text(self: TreeNode)=value

"""

 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text that appears when the mouse pointer hovers over a System.Windows.Forms.TreeNode.



Get: ToolTipText(self: TreeNode) -> str



Set: ToolTipText(self: TreeNode)=value

"""

 TreeView=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the parent tree view that the tree node is assigned to.



Get: TreeView(self: TreeNode) -> TreeView



"""





class MaskedTextProvider(object,ICloneable):
 """
 Represents a mask-parsing service that can be used by any number of controls that support masking,such as the System.Windows.Forms.MaskedTextBox control.

 

 MaskedTextProvider(mask: str)

 MaskedTextProvider(mask: str,restrictToAscii: bool)

 MaskedTextProvider(mask: str,culture: CultureInfo)

 MaskedTextProvider(mask: str,culture: CultureInfo,restrictToAscii: bool)

 MaskedTextProvider(mask: str,passwordChar: Char,allowPromptAsInput: bool)

 MaskedTextProvider(mask: str,culture: CultureInfo,passwordChar: Char,allowPromptAsInput: bool)

 MaskedTextProvider(mask: str,culture: CultureInfo,allowPromptAsInput: bool,promptChar: Char,passwordChar: Char,restrictToAscii: bool)
 """
 def Add(self,input,testPosition=None,resultHint=None):
  """
  Add(self: MaskedTextProvider,input: str) -> bool

  

   Adds the characters in the specified input string to the end of the formatted string.

  

   input: A System.String containing character values to be appended to the formatted string.

   Returns: true if all the characters from the input string were added successfully; otherwise false to 

    indicate that no characters were added.

  

  Add(self: MaskedTextProvider,input: str) -> (bool,int,MaskedTextResultHint)

  

   Adds the characters in the specified input string to the end of the formatted string,and then 

    outputs position and descriptive information.

  

  

   input: A System.String containing character values to be appended to the formatted string.

   Returns: true if all the characters from the input string were added successfully; otherwise false to 

    indicate that no characters were added.

  

  Add(self: MaskedTextProvider,input: Char) -> bool

  

   Adds the specified input character to the end of the formatted string.

  

   input: A System.Char value to be appended to the formatted string.

   Returns: true if the input character was added successfully; otherwise false.

  Add(self: MaskedTextProvider,input: Char) -> (bool,int,MaskedTextResultHint)

  

   Adds the specified input character to the end of the formatted string,and then outputs position 

    and descriptive information.

  

  

   input: A System.Char value to be appended to the formatted string.

   Returns: true if the input character was added successfully; otherwise false.
  """
  pass
 def Clear(self,resultHint=None):
  """
  Clear(self: MaskedTextProvider) -> MaskedTextResultHint

  

   Clears all the editable input characters from the formatted string,replacing them with prompt 

    characters,and then outputs descriptive information.

  

  Clear(self: MaskedTextProvider)

   Clears all the editable input characters from the formatted string,replacing them with prompt 

    characters.
  """
  pass
 def Clone(self):
  """
  Clone(self: MaskedTextProvider) -> object

  

   Creates a copy of the current System.ComponentModel.MaskedTextProvider.

   Returns: The System.ComponentModel.MaskedTextProvider object this method creates,cast as an object.
  """
  pass
 def FindAssignedEditPositionFrom(self,position,direction):
  """
  FindAssignedEditPositionFrom(self: MaskedTextProvider,position: int,direction: bool) -> int

  

   Returns the position of the first assigned editable position after the specified position using 

    the specified search direction.

  

  

   position: The zero-based position in the formatted string to start the search.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first assigned 

    editable position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindAssignedEditPositionInRange(self,startPosition,endPosition,direction):
  """
  FindAssignedEditPositionInRange(self: MaskedTextProvider,startPosition: int,endPosition: int,direction: bool) -> int

  

   Returns the position of the first assigned editable position between the specified positions 

    using the specified search direction.

  

  

   startPosition: The zero-based position in the formatted string where the search starts.

   endPosition: The zero-based position in the formatted string where the search ends.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first assigned 

    editable position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindEditPositionFrom(self,position,direction):
  """
  FindEditPositionFrom(self: MaskedTextProvider,position: int,direction: bool) -> int

  

   Returns the position of the first editable position after the specified position using the 

    specified search direction.

  

  

   position: The zero-based position in the formatted string to start the search.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first editable 

    position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindEditPositionInRange(self,startPosition,endPosition,direction):
  """
  FindEditPositionInRange(self: MaskedTextProvider,startPosition: int,endPosition: int,direction: bool) -> int

  

   Returns the position of the first editable position between the specified positions using the 

    specified search direction.

  

  

   startPosition: The zero-based position in the formatted string where the search starts.

   endPosition: The zero-based position in the formatted string where the search ends.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first editable 

    position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindNonEditPositionFrom(self,position,direction):
  """
  FindNonEditPositionFrom(self: MaskedTextProvider,position: int,direction: bool) -> int

  

   Returns the position of the first non-editable position after the specified position using the 

    specified search direction.

  

  

   position: The zero-based position in the formatted string to start the search.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first literal 

    position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindNonEditPositionInRange(self,startPosition,endPosition,direction):
  """
  FindNonEditPositionInRange(self: MaskedTextProvider,startPosition: int,endPosition: int,direction: bool) -> int

  

   Returns the position of the first non-editable position between the specified positions using 

    the specified search direction.

  

  

   startPosition: The zero-based position in the formatted string where the search starts.

   endPosition: The zero-based position in the formatted string where the search ends.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first literal 

    position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindUnassignedEditPositionFrom(self,position,direction):
  """
  FindUnassignedEditPositionFrom(self: MaskedTextProvider,position: int,direction: bool) -> int

  

   Returns the position of the first unassigned editable position after the specified position 

    using the specified search direction.

  

  

   position: The zero-based position in the formatted string to start the search.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first unassigned 

    editable position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 def FindUnassignedEditPositionInRange(self,startPosition,endPosition,direction):
  """
  FindUnassignedEditPositionInRange(self: MaskedTextProvider,startPosition: int,endPosition: int,direction: bool) -> int

  

   Returns the position of the first unassigned editable position between the specified positions 

    using the specified search direction.

  

  

   startPosition: The zero-based position in the formatted string where the search starts.

   endPosition: The zero-based position in the formatted string where the search ends.

   direction: A System.Boolean indicating the search direction; either true to search forward or false to 

    search backward.

  

   Returns: If successful,an System.Int32 representing the zero-based position of the first unassigned 

    editable position encountered; otherwise System.ComponentModel.MaskedTextProvider.InvalidIndex.
  """
  pass
 @staticmethod
 def GetOperationResultFromHint(hint):
  """
  GetOperationResultFromHint(hint: MaskedTextResultHint) -> bool

  

   Determines whether the specified System.ComponentModel.MaskedTextResultHint denotes success or 

    failure.

  

  

   hint: A System.ComponentModel.MaskedTextResultHint value typically obtained as an output parameter 

    from a previous operation.

  

   Returns: true if the specified System.ComponentModel.MaskedTextResultHint value represents a success; 

    otherwise,false if it represents failure.
  """
  pass
 def InsertAt(self,input,position,testPosition=None,resultHint=None):
  """
  InsertAt(self: MaskedTextProvider,input: str,position: int) -> bool

  

   Inserts the specified string at a specified position within the formatted string.

  

   input: The System.String to be inserted.

   position: The zero-based position in the formatted string to insert the input string.

   Returns: true if the insertion was successful; otherwise,false.

  InsertAt(self: MaskedTextProvider,input: str,position: int) -> (bool,int,MaskedTextResultHint)

  

   Inserts the specified string at a specified position within the formatted string,returning the 

    last insertion position and the status of the operation.

  

  

   input: The System.String to be inserted.

   position: The zero-based position in the formatted string to insert the input string.

   Returns: true if the insertion was successful; otherwise,false.

  InsertAt(self: MaskedTextProvider,input: Char,position: int) -> bool

  

   Inserts the specified character at the specified position within the formatted string.

  

   input: The System.Char to be inserted.

   position: The zero-based position in the formatted string to insert the character.

   Returns: true if the insertion was successful; otherwise,false.

  InsertAt(self: MaskedTextProvider,input: Char,position: int) -> (bool,int,MaskedTextResultHint)

  

   Inserts the specified character at the specified position within the formatted string,returning 

    the last insertion position and the status of the operation.

  

  

   input: The System.Char to be inserted.

   position: The zero-based position in the formatted string to insert the character.

   Returns: true if the insertion was successful; otherwise,false.
  """
  pass
 def IsAvailablePosition(self,position):
  """
  IsAvailablePosition(self: MaskedTextProvider,position: int) -> bool

  

   Determines whether the specified position is available for assignment.

  

   position: The zero-based position in the mask to test.

   Returns: true if the specified position in the formatted string is editable and has not been assigned to 

    yet; otherwise false.
  """
  pass
 def IsEditPosition(self,position):
  """
  IsEditPosition(self: MaskedTextProvider,position: int) -> bool

  

   Determines whether the specified position is editable.

  

   position: The zero-based position in the mask to test.

   Returns: true if the specified position in the formatted string is editable; otherwise false.
  """
  pass
 @staticmethod
 def IsValidInputChar(c):
  """
  IsValidInputChar(c: Char) -> bool

  

   Determines whether the specified character is a valid input character.

  

   c: The System.Char value to test.

   Returns: true if the specified character contains a valid input value; otherwise false.
  """
  pass
 @staticmethod
 def IsValidMaskChar(c):
  """
  IsValidMaskChar(c: Char) -> bool

  

   Determines whether the specified character is a valid mask character.

  

   c: The System.Char value to test.

   Returns: true if the specified character contains a valid mask value; otherwise false.
  """
  pass
 @staticmethod
 def IsValidPasswordChar(c):
  """
  IsValidPasswordChar(c: Char) -> bool

  

   Determines whether the specified character is a valid password character.

  

   c: The System.Char value to test.

   Returns: true if the specified character contains a valid password value; otherwise false.
  """
  pass
 def Remove(self,testPosition=None,resultHint=None):
  """
  Remove(self: MaskedTextProvider) -> (bool,int,MaskedTextResultHint)

  

   Removes the last assigned character from the formatted string,and then outputs the removal 

    position and descriptive information.

  

   Returns: true if the character was successfully removed; otherwise,false.

  Remove(self: MaskedTextProvider) -> bool

  

   Removes the last assigned character from the formatted string.

   Returns: true if the character was successfully removed; otherwise,false.
  """
  pass
 def RemoveAt(self,*__args):
  """
  RemoveAt(self: MaskedTextProvider,startPosition: int,endPosition: int) -> (bool,int,MaskedTextResultHint)

  

   Removes the assigned characters between the specified positions from the formatted string,and 

    then outputs the removal position and descriptive information.

  

  

   startPosition: The zero-based index of the first assigned character to remove.

   endPosition: The zero-based index of the last assigned character to remove.

   Returns: true if the character was successfully removed; otherwise,false.

  RemoveAt(self: MaskedTextProvider,startPosition: int,endPosition: int) -> bool

  

   Removes the assigned characters between the specified positions from the formatted string.

  

   startPosition: The zero-based index of the first assigned character to remove.

   endPosition: The zero-based index of the last assigned character to remove.

   Returns: true if the character was successfully removed; otherwise,false.

  RemoveAt(self: MaskedTextProvider,position: int) -> bool

  

   Removes the assigned character at the specified position from the formatted string.

  

   position: The zero-based position of the assigned character to remove.

   Returns: true if the character was successfully removed; otherwise,false.
  """
  pass
 def Replace(self,input,*__args):
  """
  Replace(self: MaskedTextProvider,input: str,position: int) -> bool

  

   Replaces a range of editable characters starting at the specified position with the specified 

    string.

  

  

   input: The System.String value used to replace the existing editable characters.

   position: The zero-based position to search for the first editable character to replace.

   Returns: true if all the characters were successfully replaced; otherwise,false.

  Replace(self: MaskedTextProvider,input: str,position: int) -> (bool,int,MaskedTextResultHint)

  

   Replaces a range of editable characters starting at the specified position with the specified 

    string,and then outputs the removal position and descriptive information.

  

  

   input: The System.String value used to replace the existing editable characters.

   position: The zero-based position to search for the first editable character to replace.

   Returns: true if all the characters were successfully replaced; otherwise,false.

  Replace(self: MaskedTextProvider,input: str,startPosition: int,endPosition: int) -> (bool,int,MaskedTextResultHint)

  

   Replaces a range of editable characters between the specified starting and ending positions with 

    the specified string,and then outputs the removal position and descriptive information.

  

  

   input: The System.String value used to replace the existing editable characters.

   startPosition: The zero-based position in the formatted string where the replacement starts.

   endPosition: The zero-based position in the formatted string where the replacement ends.

   Returns: true if all the characters were successfully replaced; otherwise,false.

  Replace(self: MaskedTextProvider,input: Char,position: int) -> bool

  

   Replaces a single character at or beyond the specified position with the specified character 

    value.

  

  

   input: The System.Char value that replaces the existing value.

   position: The zero-based position to search for the first editable character to replace.

   Returns: true if the character was successfully replaced; otherwise,false.

  Replace(self: MaskedTextProvider,input: Char,position: int) -> (bool,int,MaskedTextResultHint)

  

   Replaces a single character at or beyond the specified position with the specified character 

    value,and then outputs the removal position and descriptive information.

  

  

   input: The System.Char value that replaces the existing value.

   position: The zero-based position to search for the first editable character to replace.

   Returns: true if the character was successfully replaced; otherwise,false.

  Replace(self: MaskedTextProvider,input: Char,startPosition: int,endPosition: int) -> (bool,int,MaskedTextResultHint)

  

   Replaces a single character between the specified starting and ending positions with the 

    specified character value,and then outputs the removal position and descriptive information.

  

  

   input: The System.Char value that replaces the existing value.

   startPosition: The zero-based position in the formatted string where the replacement starts.

   endPosition: The zero-based position in the formatted string where the replacement ends.

   Returns: true if the character was successfully replaced; otherwise,false.
  """
  pass
 def Set(self,input,testPosition=None,resultHint=None):
  """
  Set(self: MaskedTextProvider,input: str) -> (bool,int,MaskedTextResultHint)

  

   Sets the formatted string to the specified input string,and then outputs the removal position 

    and descriptive information.

  

  

   input: The System.String value used to set the formatted string.

   Returns: true if all the characters were successfully set; otherwise,false.

  Set(self: MaskedTextProvider,input: str) -> bool

  

   Sets the formatted string to the specified input string.

  

   input: The System.String value used to set the formatted string.

   Returns: true if all the characters were successfully set; otherwise,false.
  """
  pass
 def ToDisplayString(self):
  """
  ToDisplayString(self: MaskedTextProvider) -> str

  

   Returns the formatted string in a displayable form.

   Returns: The formatted System.String that includes prompts and mask literals.
  """
  pass
 def ToString(self,*__args):
  """
  ToString(self: MaskedTextProvider,includePrompt: bool,includeLiterals: bool) -> str

  

   Returns the formatted string,optionally including prompt and literal characters.

  

   includePrompt: true to include prompt characters in the return string; otherwise,false.

   includeLiterals: true to include literal characters in the return string; otherwise,false.

   Returns: The formatted System.String that includes all the assigned character values and optionally 

    includes literals and prompts.

  

  ToString(self: MaskedTextProvider,includePrompt: bool,includeLiterals: bool,startPosition: int,length: int) -> str

  

   Returns a substring of the formatted string,optionally including prompt and literal characters.

  

   includePrompt: true to include prompt characters in the return string; otherwise,false.

   includeLiterals: true to include literal characters in the return string; otherwise,false.

   startPosition: The zero-based position in the formatted string where the output begins.

   length: The number of characters to return.

   Returns: If successful,a substring of the formatted System.String,which includes all the assigned 

    character values and optionally includes literals and prompts; otherwise the System.String.Empty 

    string.

  

  ToString(self: MaskedTextProvider,ignorePasswordChar: bool,includePrompt: bool,includeLiterals: bool,startPosition: int,length: int) -> str

  

   Returns a substring of the formatted string,optionally including prompt,literal,and password 

    characters.

  

  

   ignorePasswordChar: true to return the actual editable characters; otherwise,false to indicate that the 

    System.ComponentModel.MaskedTextProvider.PasswordChar property is to be honored.

  

   includePrompt: true to include prompt characters in the return string; otherwise,false.

   includeLiterals: true to return literal characters in the return string; otherwise,false.

   startPosition: The zero-based position in the formatted string where the output begins.

   length: The number of characters to return.

   Returns: If successful,a substring of the formatted System.String,which includes all the assigned 

    character values and optionally includes literals,prompts,and password characters; otherwise 

    the System.String.Empty string.

  

  ToString(self: MaskedTextProvider,ignorePasswordChar: bool,startPosition: int,length: int) -> str

  

   Returns a substring of the formatted string,optionally including password characters.

  

   ignorePasswordChar: true to return the actual editable characters; otherwise,false to indicate that the 

    System.ComponentModel.MaskedTextProvider.PasswordChar property is to be honored.

  

   startPosition: The zero-based position in the formatted string where the output begins.

   length: The number of characters to return.

   Returns: If successful,a substring of the formatted System.String,which includes literals,prompts,and 

    optionally password characters; otherwise the System.String.Empty string.

  

  ToString(self: MaskedTextProvider) -> str

  

   Returns the formatted string that includes all the assigned character values.

   Returns: The formatted System.String that includes all the assigned character values.

  ToString(self: MaskedTextProvider,ignorePasswordChar: bool) -> str

  

   Returns the formatted string,optionally including password characters.

  

   ignorePasswordChar: true to return the actual editable characters; otherwise,false to indicate that the 

    System.ComponentModel.MaskedTextProvider.PasswordChar property is to be honored.

  

   Returns: The formatted System.String that includes literals,prompts,and optionally password characters.

  ToString(self: MaskedTextProvider,startPosition: int,length: int) -> str

  

   Returns a substring of the formatted string.

  

   startPosition: The zero-based position in the formatted string where the output begins.

   length: The number of characters to return.

   Returns: If successful,a substring of the formatted System.String,which includes all the assigned 

    character values; otherwise the System.String.Empty string.
  """
  pass
 def VerifyChar(self,input,position,hint):
  """
  VerifyChar(self: MaskedTextProvider,input: Char,position: int) -> (bool,MaskedTextResultHint)

  

   Tests whether the specified character could be set successfully at the specified position.

  

   input: The System.Char value to test.

   position: The position in the mask to test the input character against.

   Returns: true if the specified character is valid for the specified position; otherwise,false.
  """
  pass
 def VerifyEscapeChar(self,input,position):
  """
  VerifyEscapeChar(self: MaskedTextProvider,input: Char,position: int) -> bool

  

   Tests whether the specified character would be escaped at the specified position.

  

   input: The System.Char value to test.

   position: The position in the mask to test the input character against.

   Returns: true if the specified character would be escaped at the specified position; otherwise,false.
  """
  pass
 def VerifyString(self,input,testPosition=None,resultHint=None):
  """
  VerifyString(self: MaskedTextProvider,input: str) -> (bool,int,MaskedTextResultHint)

  

   Tests whether the specified string could be set successfully,and then outputs position and 

    descriptive information.

  

  

   input: The System.String value to test.

   Returns: true if the specified string represents valid input; otherwise,false.

  VerifyString(self: MaskedTextProvider,input: str) -> bool

  

   Tests whether the specified string could be set successfully.

  

   input: The System.String value to test.

   Returns: true if the specified string represents valid input; otherwise,false.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,mask,*__args):
  """
  __new__(cls: type,mask: str)

  __new__(cls: type,mask: str,restrictToAscii: bool)

  __new__(cls: type,mask: str,culture: CultureInfo)

  __new__(cls: type,mask: str,culture: CultureInfo,restrictToAscii: bool)

  __new__(cls: type,mask: str,passwordChar: Char,allowPromptAsInput: bool)

  __new__(cls: type,mask: str,culture: CultureInfo,passwordChar: Char,allowPromptAsInput: bool)

  __new__(cls: type,mask: str,culture: CultureInfo,allowPromptAsInput: bool,promptChar: Char,passwordChar: Char,restrictToAscii: bool)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 AllowPromptAsInput=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the prompt character should be treated as a valid input character or not.



Get: AllowPromptAsInput(self: MaskedTextProvider) -> bool



"""

 AsciiOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the mask accepts characters outside of the ASCII character set.



Get: AsciiOnly(self: MaskedTextProvider) -> bool



"""

 AssignedEditPositionCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of editable character positions that have already been successfully assigned an input value.



Get: AssignedEditPositionCount(self: MaskedTextProvider) -> int



"""

 AvailableEditPositionCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of editable character positions in the input mask that have not yet been assigned an input value.



Get: AvailableEditPositionCount(self: MaskedTextProvider) -> int



"""

 Culture=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the culture that determines the value of the localizable separators and placeholders in the input mask.



Get: Culture(self: MaskedTextProvider) -> CultureInfo



"""

 EditPositionCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of editable positions in the formatted string.



Get: EditPositionCount(self: MaskedTextProvider) -> int



"""

 EditPositions=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a newly created enumerator for the editable positions in the formatted string.



Get: EditPositions(self: MaskedTextProvider) -> IEnumerator



"""

 IncludeLiterals=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether literal characters in the input mask should be included in the formatted string.



Get: IncludeLiterals(self: MaskedTextProvider) -> bool



Set: IncludeLiterals(self: MaskedTextProvider)=value

"""

 IncludePrompt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether System.Windows.Forms.MaskedTextBox.PromptChar is used to represent the absence of user input when displaying the formatted string.



Get: IncludePrompt(self: MaskedTextProvider) -> bool



Set: IncludePrompt(self: MaskedTextProvider)=value

"""

 IsPassword=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that determines whether password protection should be applied to the formatted string.



Get: IsPassword(self: MaskedTextProvider) -> bool



Set: IsPassword(self: MaskedTextProvider)=value

"""

 LastAssignedPosition=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the index in the mask of the rightmost input character that has been assigned to the mask.



Get: LastAssignedPosition(self: MaskedTextProvider) -> int



"""

 Length=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the mask,absent any mask modifier characters.



Get: Length(self: MaskedTextProvider) -> int



"""

 Mask=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the input mask.



Get: Mask(self: MaskedTextProvider) -> str



"""

 MaskCompleted=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether all required inputs have been entered into the formatted string.



Get: MaskCompleted(self: MaskedTextProvider) -> bool



"""

 MaskFull=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether all required and optional inputs have been entered into the formatted string.



Get: MaskFull(self: MaskedTextProvider) -> bool



"""

 PasswordChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the character to be substituted for the actual input characters.



Get: PasswordChar(self: MaskedTextProvider) -> Char



Set: PasswordChar(self: MaskedTextProvider)=value

"""

 PromptChar=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the character used to represent the absence of user input for all available edit positions.



Get: PromptChar(self: MaskedTextProvider) -> Char



Set: PromptChar(self: MaskedTextProvider)=value

"""

 ResetOnPrompt=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that determines how an input character that matches the prompt character should be handled.



Get: ResetOnPrompt(self: MaskedTextProvider) -> bool



Set: ResetOnPrompt(self: MaskedTextProvider)=value

"""

 ResetOnSpace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that determines how a space input character should be handled.



Get: ResetOnSpace(self: MaskedTextProvider) -> bool



Set: ResetOnSpace(self: MaskedTextProvider)=value

"""

 SkipLiterals=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether literal character positions in the mask can be overwritten by their same values.



Get: SkipLiterals(self: MaskedTextProvider) -> bool



Set: SkipLiterals(self: MaskedTextProvider)=value

"""


 DefaultPasswordChar=None
 InvalidIndex=-1




class DoWorkEventArgs(CancelEventArgs):
 """
 Provides data for the System.ComponentModel.BackgroundWorker.DoWork event handler.

 

 DoWorkEventArgs(argument: object)
 """
 @staticmethod
 def __new__(self,argument):
  """ __new__(cls: type,argument: object) """
  pass
 Argument=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that represents the argument of an asynchronous operation.



Get: Argument(self: DoWorkEventArgs) -> object



"""

 Result=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that represents the result of an asynchronous operation.



Get: Result(self: DoWorkEventArgs) -> object



Set: Result(self: DoWorkEventArgs)=value

"""





class ObjectAce(QualifiedAce):
 """
 Controls access to Directory Services objects. This class represents an Access Control Entry (ACE) associated with a directory object.

 

 ObjectAce(aceFlags: AceFlags,qualifier: AceQualifier,accessMask: int,sid: SecurityIdentifier,flags: ObjectAceFlags,type: Guid,inheritedType: Guid,isCallback: bool,opaque: Array[Byte])
 """
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: ObjectAce,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.ObjectAce object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.ObjectAce is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 @staticmethod
 def MaxOpaqueLength(isCallback):
  """
  MaxOpaqueLength(isCallback: bool) -> int

  

   Returns the maximum allowed length,in bytes,of an opaque data BLOB for callback Access Control 

    Entries (ACEs).

  

  

   isCallback: True if the System.Security.AccessControl.ObjectAce is a callback ACE type.

   Returns: The maximum allowed length,in bytes,of an opaque data BLOB for callback Access Control Entries 

    (ACEs).
  """
  pass
 @staticmethod
 def __new__(self,aceFlags,qualifier,accessMask,sid,flags,type,inheritedType,isCallback,opaque):
  """ __new__(cls: type,aceFlags: AceFlags,qualifier: AceQualifier,accessMask: int,sid: SecurityIdentifier,flags: ObjectAceFlags,type: Guid,inheritedType: Guid,isCallback: bool,opaque: Array[Byte]) """
  pass
 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.ObjectAce object. This length should be used before marshaling the ACL into a binary array with the System.Security.AccessControl.ObjectAce.GetBinaryForm method.



Get: BinaryLength(self: ObjectAce) -> int



"""

 InheritedObjectAceType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the GUID of the object type that can inherit the Access Control Entry (ACE) that this System.Security.AccessControl.ObjectAce object represents.



Get: InheritedObjectAceType(self: ObjectAce) -> Guid



Set: InheritedObjectAceType(self: ObjectAce)=value

"""

 ObjectAceFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets flags that specify whether the System.Security.AccessControl.ObjectAce.ObjectAceType and System.Security.AccessControl.ObjectAce.InheritedObjectAceType properties contain values that identify valid object types.



Get: ObjectAceFlags(self: ObjectAce) -> ObjectAceFlags



Set: ObjectAceFlags(self: ObjectAce)=value

"""

 ObjectAceType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the GUID of the object type associated with this System.Security.AccessControl.ObjectAce object.



Get: ObjectAceType(self: ObjectAce) -> Guid



Set: ObjectAceType(self: ObjectAce)=value

"""





class DriveType(Enum,IComparable,IFormattable,IConvertible):
 """
 Defines constants for drive types,including CDRom,Fixed,Network,NoRootDirectory,Ram,Removable,and Unknown.

 

 enum DriveType,values: CDRom (5),Fixed (3),Network (4),NoRootDirectory (1),Ram (6),Removable (2),Unknown (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 CDRom=None
 Fixed=None
 Network=None
 NoRootDirectory=None
 Ram=None
 Removable=None
 Unknown=None
 value__=None




class ICredentialsByHost:
 """ Provides the interface for retrieving credentials for a host,port,and authentication type. """
 def GetCredential(self,host,port,authenticationType):
  """
  GetCredential(self: ICredentialsByHost,host: str,port: int,authenticationType: str) -> NetworkCredential

  

   Returns the credential for the specified host,port,and authentication protocol.

  

   host: The host computer that is authenticating the client.

   port: The port on host that the client will communicate with.

   authenticationType: The authentication protocol.

   Returns: A System.Net.NetworkCredential for the specified host,port,and authentication protocol,or 

    null if there are no credentials available for the specified host,port,and authentication 

    protocol.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class ListViewItemConverter(ExpandableObjectConverter):
 """
 Provides a type converter to convert System.Windows.Forms.ListViewItem objects to and from various other representations.

 

 ListViewItemConverter()
 """
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: ListViewItemConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Gets a value indicating whether this converter can convert an object to the given destination 

    type using the context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   destinationType: A System.Type that represents the type you wish to convert to.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ListViewItemConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the given object to another type.

  

   context: A formatter context. This object can be used to extract additional information about the 

    environment this converter is being invoked from. This may be null,so you should always check. 

    Also,properties on the context object may also return null.

  

   culture: An optional culture info. If not supplied the current culture is assumed.

   value: The object to convert.

   destinationType: The type to convert the object to.

   Returns: The converted object.
  """
  pass



class CommonSecurityDescriptor(GenericSecurityDescriptor):
 """
 Represents a security descriptor. A security descriptor includes an owner,a primary group,a Discretionary Access Control List (DACL),and a System Access Control List (SACL).

 

 CommonSecurityDescriptor(isContainer: bool,isDS: bool,flags: ControlFlags,owner: SecurityIdentifier,group: SecurityIdentifier,systemAcl: SystemAcl,discretionaryAcl: DiscretionaryAcl)

 CommonSecurityDescriptor(isContainer: bool,isDS: bool,rawSecurityDescriptor: RawSecurityDescriptor)

 CommonSecurityDescriptor(isContainer: bool,isDS: bool,sddlForm: str)

 CommonSecurityDescriptor(isContainer: bool,isDS: bool,binaryForm: Array[Byte],offset: int)
 """
 def AddDiscretionaryAcl(self,revision,trusted):
  """ AddDiscretionaryAcl(self: CommonSecurityDescriptor,revision: Byte,trusted: int) """
  pass
 def AddSystemAcl(self,revision,trusted):
  """ AddSystemAcl(self: CommonSecurityDescriptor,revision: Byte,trusted: int) """
  pass
 def PurgeAccessControl(self,sid):
  """
  PurgeAccessControl(self: CommonSecurityDescriptor,sid: SecurityIdentifier)

   Removes all access rules for the specified security identifier from the Discretionary Access 

    Control List (DACL) associated with this System.Security.AccessControl.CommonSecurityDescriptor 

    object.

  

  

   sid: The security identifier for which to remove access rules.
  """
  pass
 def PurgeAudit(self,sid):
  """
  PurgeAudit(self: CommonSecurityDescriptor,sid: SecurityIdentifier)

   Removes all audit rules for the specified security identifier from the System Access Control 

    List (SACL) associated with this System.Security.AccessControl.CommonSecurityDescriptor object.

  

  

   sid: The security identifier for which to remove audit rules.
  """
  pass
 def SetDiscretionaryAclProtection(self,isProtected,preserveInheritance):
  """
  SetDiscretionaryAclProtection(self: CommonSecurityDescriptor,isProtected: bool,preserveInheritance: bool)

   Sets the inheritance protection for the Discretionary Access Control List (DACL) associated with 

    this System.Security.AccessControl.CommonSecurityDescriptor object. DACLs that are protected do 

    not inherit access rules from parent containers.

  

  

   isProtected: true to protect the DACL from inheritance.

   preserveInheritance: true to keep inherited access rules in the DACL; false to remove inherited access rules from the 

    DACL.
  """
  pass
 def SetSystemAclProtection(self,isProtected,preserveInheritance):
  """
  SetSystemAclProtection(self: CommonSecurityDescriptor,isProtected: bool,preserveInheritance: bool)

   Sets the inheritance protection for the System Access Control List (SACL) associated with this 

    System.Security.AccessControl.CommonSecurityDescriptor object. SACLs that are protected do not 

    inherit audit rules from parent containers.

  

  

   isProtected: true to protect the SACL from inheritance.

   preserveInheritance: true to keep inherited audit rules in the SACL; false to remove inherited audit rules from the 

    SACL.
  """
  pass
 @staticmethod
 def __new__(self,isContainer,isDS,*__args):
  """
  __new__(cls: type,isContainer: bool,isDS: bool,flags: ControlFlags,owner: SecurityIdentifier,group: SecurityIdentifier,systemAcl: SystemAcl,discretionaryAcl: DiscretionaryAcl)

  __new__(cls: type,isContainer: bool,isDS: bool,rawSecurityDescriptor: RawSecurityDescriptor)

  __new__(cls: type,isContainer: bool,isDS: bool,sddlForm: str)

  __new__(cls: type,isContainer: bool,isDS: bool,binaryForm: Array[Byte],offset: int)
  """
  pass
 ControlFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets values that specify behavior of the System.Security.AccessControl.CommonSecurityDescriptor object.



Get: ControlFlags(self: CommonSecurityDescriptor) -> ControlFlags



"""

 DiscretionaryAcl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the discretionary access control list (DACL) for this System.Security.AccessControl.CommonSecurityDescriptor object. The DACL contains access rules.



Get: DiscretionaryAcl(self: CommonSecurityDescriptor) -> DiscretionaryAcl



Set: DiscretionaryAcl(self: CommonSecurityDescriptor)=value

"""

 Group=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the primary group for this System.Security.AccessControl.CommonSecurityDescriptor object.



Get: Group(self: CommonSecurityDescriptor) -> SecurityIdentifier



Set: Group(self: CommonSecurityDescriptor)=value

"""

 IsContainer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether the object associated with this System.Security.AccessControl.CommonSecurityDescriptor object is a container object.



Get: IsContainer(self: CommonSecurityDescriptor) -> bool



"""

 IsDiscretionaryAclCanonical=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether the Discretionary Access Control List (DACL) associated with this System.Security.AccessControl.CommonSecurityDescriptor object is in canonical order.



Get: IsDiscretionaryAclCanonical(self: CommonSecurityDescriptor) -> bool



"""

 IsDS=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether the object associated with this System.Security.AccessControl.CommonSecurityDescriptor object is a directory object.



Get: IsDS(self: CommonSecurityDescriptor) -> bool



"""

 IsSystemAclCanonical=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a Boolean value that specifies whether the System Access Control List (SACL) associated with this System.Security.AccessControl.CommonSecurityDescriptor object is in canonical order.



Get: IsSystemAclCanonical(self: CommonSecurityDescriptor) -> bool



"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the owner of the object associated with this System.Security.AccessControl.CommonSecurityDescriptor object.



Get: Owner(self: CommonSecurityDescriptor) -> SecurityIdentifier



Set: Owner(self: CommonSecurityDescriptor)=value

"""

 SystemAcl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System Access Control List (SACL) for this System.Security.AccessControl.CommonSecurityDescriptor object. The SACL contains audit rules.



Get: SystemAcl(self: CommonSecurityDescriptor) -> SystemAcl



Set: SystemAcl(self: CommonSecurityDescriptor)=value

"""





import sys
import imp

from rpw.utils.logger import logger


class MockObject(object):
    """
    This gets passed back as an object when an import fails but is listed
    in dotnet_modules. This objects can have attributes retrieved, be
    iterated and called to allow for code to run without errors.
    This is used only when clr import fail, meaning code is being executed
    outside of Revit (sphinx)
    """
    # Defines for custom override for objects where the type is important
    # This is needed for example, so forms won't inherit form MockObject
    # which breaks sphinx autodoc
    MOCK_OVERRIDE = {'System.Windows.Window': object,
                     'Controls.Label': object,
                     'Controls.Button': object,
                     'Controls.TextBox': object,
                     'Controls.CheckBox': object,
                     'Controls.ComboBox': object,
                     'Controls.Separator': object,
                     }

    def __init__(self, *args, **kwargs):
        self.fullname = kwargs.get('fullname', '<Unamed Import>')

    def __getattr__(self, attr):
        logger.debug("Getting Atts:{} from {}')".format(attr, self.fullname))
        path_and_attr = '.'.join([self.fullname, attr])
        # print(path_and_attr)
        if path_and_attr in MockObject.MOCK_OVERRIDE:
            return MockObject.MOCK_OVERRIDE[path_and_attr]
        return MockObject(fullname=attr)

    def __iter__(self):
        yield iter(self)

    def AddReference(self, namespace):
        logger.debug("Mock.clr.AddReference('{}')".format(namespace))

    def __call__(self, *args, **kwargs):
        return MockObject(*args, **kwargs)

    def __repr__(self):
        return self.fullname

    def __str__(self):
        return self.fullname


class MockImporter(object):
    # https://github.com/gtalarico/revitpythonwrapper/issues/3
    # http://dangerontheranger.blogspot.com/2012/07/how-to-use-sysmetapath-with-python.html
    # http://blog.dowski.com/2008/07/31/customizing-the-python-import-system/

    dotnet_modules = ['clr',
                      'Autodesk',
                      'RevitServices',
                      'IronPython',
                      'System',
                      'wpf',
                      'Rhino',
                      ]

    def find_module(self, fullname, path=None):
        logger.debug('Loading : {}'.format(fullname))
        for module in self.dotnet_modules:
            if fullname.startswith(module):
                return self
        return None

    def load_module(self, fullname):
        """This method is called by Python if CustomImporter.find_module
           does not return None. fullname is the fully-qualified name
           of the module/package that was requested."""
        if fullname in sys.modules:
            return sys.modules[fullname]
        else:
            logger.debug('Importing Mock Module: {}'.format(fullname))
            # mod = imp.new_module(fullname)
            # import pdb; pdb.set_trace()
            mod = MockObject(fullname=fullname)
            mod.__loader__ = self
            mod.__file__ = fullname
            mod.__path__ = [fullname]
            mod.__name__ = fullname
            sys.modules[fullname] = mod
            return mod  # This gives errors



class Char(object,IComparable,IConvertible,IComparable[Char],IEquatable[Char]):
 """ Represents a character as a UTF-16 code unit. """
 def CompareTo(self,value):
  """
  CompareTo(self: Char,value: Char) -> int

  

   Compares this instance to a specified System.Char object and indicates whether this instance 

    precedes,follows,or appears in the same position in the sort order as the specified 

    System.Char object.

  

  

   value: A System.Char object to compare.

   Returns: A signed number indicating the position of this instance in the sort order in relation to the 

    value parameter.Return Value Description Less than zero This instance precedes value. Zero This 

    instance has the same position in the sort order as value. Greater than zero This instance 

    follows value.

  

  CompareTo(self: Char,value: object) -> int

  

   Compares this instance to a specified object and indicates whether this instance precedes,

    follows,or appears in the same position in the sort order as the specified System.Object.

  

  

   value: An object to compare this instance to,or null.

   Returns: A signed number indicating the position of this instance in the sort order in relation to the 

    value parameter.Return Value Description Less than zero This instance precedes value. Zero This 

    instance has the same position in the sort order as value. Greater than zero This instance 

    follows value.-or- value is null.
  """
  pass
 @staticmethod
 def ConvertFromUtf32(utf32):
  """
  ConvertFromUtf32(utf32: int) -> str

  

   Converts the specified Unicode code point into a UTF-16 encoded string.

  

   utf32: A 21-bit Unicode code point.

   Returns: A string consisting of one System.Char object or a surrogate pair of System.Char objects 

    equivalent to the code point specified by the utf32 parameter.
  """
  pass
 @staticmethod
 def ConvertToUtf32(*__args):
  """
  ConvertToUtf32(s: str,index: int) -> int

  

   Converts the value of a UTF-16 encoded character or surrogate pair at a specified position in a 

    string into a Unicode code point.

  

  

   s: A string that contains a character or surrogate pair.

   index: The index position of the character or surrogate pair in s.

   Returns: The 21-bit Unicode code point represented by the character or surrogate pair at the position in 

    the s parameter specified by the index parameter.

  

  ConvertToUtf32(highSurrogate: Char,lowSurrogate: Char) -> int

  

   Converts the value of a UTF-16 encoded surrogate pair into a Unicode code point.

  

   highSurrogate: A high surrogate code unit (that is,a code unit ranging from U+D800 through U+DBFF).

   lowSurrogate: A low surrogate code unit (that is,a code unit ranging from U+DC00 through U+DFFF).

   Returns: The 21-bit Unicode code point represented by the highSurrogate and lowSurrogate parameters.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: Char,obj: Char) -> bool

  

   Returns a value that indicates whether this instance is equal to the specified System.Char 

    object.

  

  

   obj: An object to compare to this instance.

   Returns: true if the obj parameter equals the value of this instance; otherwise,false.

  Equals(self: Char,obj: object) -> bool

  

   Returns a value that indicates whether this instance is equal to a specified object.

  

   obj: An object to compare with this instance or null.

   Returns: true if obj is an instance of System.Char and equals the value of this instance; otherwise,

    false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Char) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 @staticmethod
 def GetNumericValue(*__args):
  """
  GetNumericValue(s: str,index: int) -> float

  

   Converts the numeric Unicode character at the specified position in a specified string to a 

    double-precision floating point number.

  

  

   s: A System.String.

   index: The character position in s.

   Returns: The numeric value of the character at position index in s if that character represents a number; 

    otherwise,-1.

  

  GetNumericValue(c: Char) -> float

  

   Converts the specified numeric Unicode character to a double-precision floating point number.

  

   c: The Unicode character to convert.

   Returns: The numeric value of c if that character represents a number; otherwise,-1.0.
  """
  pass
 def GetTypeCode(self):
  """
  GetTypeCode(self: Char) -> TypeCode

  

   Returns the System.TypeCode for value type System.Char.

   Returns: The enumerated constant,System.TypeCode.Char.
  """
  pass
 @staticmethod
 def GetUnicodeCategory(*__args):
  """
  GetUnicodeCategory(s: str,index: int) -> UnicodeCategory

  

   Categorizes the character at the specified position in a specified string into a group 

    identified by one of the System.Globalization.UnicodeCategory values.

  

  

   s: A System.String.

   index: The character position in s.

   Returns: A System.Globalization.UnicodeCategory enumerated constant that identifies the group that 

    contains the character at position index in s.

  

  GetUnicodeCategory(c: Char) -> UnicodeCategory

  

   Categorizes a specified Unicode character into a group identified by one of the 

    System.Globalization.UnicodeCategory values.

  

  

   c: The Unicode character to categorize.

   Returns: A System.Globalization.UnicodeCategory value that identifies the group that contains c.
  """
  pass
 @staticmethod
 def IsControl(*__args):
  """
  IsControl(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a control character.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a control character; otherwise,false.

  IsControl(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a control character.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a control character; otherwise,false.
  """
  pass
 @staticmethod
 def IsDigit(*__args):
  """
  IsDigit(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a decimal digit.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a decimal digit; otherwise,false.

  IsDigit(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a decimal digit.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a decimal digit; otherwise,false.
  """
  pass
 @staticmethod
 def IsHighSurrogate(*__args):
  """
  IsHighSurrogate(s: str,index: int) -> bool

  

   Indicates whether the System.Char object at the specified position in a string is a high 

    surrogate.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the numeric value of the specified character in the s parameter ranges from U+D800 

    through U+DBFF; otherwise,false.

  

  IsHighSurrogate(c: Char) -> bool

  

   Indicates whether the specified System.Char object is a high surrogate.

  

   c: The Unicode character to evaluate.

   Returns: true if the numeric value of the c parameter ranges from U+D800 through U+DBFF; otherwise,false.
  """
  pass
 @staticmethod
 def IsLetter(*__args):
  """
  IsLetter(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a Unicode letter.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a letter; otherwise,false.

  IsLetter(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a Unicode letter.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a letter; otherwise,false.
  """
  pass
 @staticmethod
 def IsLetterOrDigit(*__args):
  """
  IsLetterOrDigit(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a letter or a decimal digit.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a letter or a decimal digit; otherwise,false.

  IsLetterOrDigit(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a letter or a decimal digit.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a letter or a decimal digit; otherwise,false.
  """
  pass
 @staticmethod
 def IsLower(*__args):
  """
  IsLower(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a lowercase letter.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a lowercase letter; otherwise,false.

  IsLower(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a lowercase letter.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a lowercase letter; otherwise,false.
  """
  pass
 @staticmethod
 def IsLowSurrogate(*__args):
  """
  IsLowSurrogate(s: str,index: int) -> bool

  

   Indicates whether the System.Char object at the specified position in a string is a low 

    surrogate.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the numeric value of the specified character in the s parameter ranges from U+DC00 

    through U+DFFF; otherwise,false.

  

  IsLowSurrogate(c: Char) -> bool

  

   Indicates whether the specified System.Char object is a low surrogate.

  

   c: The character to evaluate.

   Returns: true if the numeric value of the c parameter ranges from U+DC00 through U+DFFF; otherwise,false.
  """
  pass
 @staticmethod
 def IsNumber(*__args):
  """
  IsNumber(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a number.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a number; otherwise,false.

  IsNumber(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a number.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a number; otherwise,false.
  """
  pass
 @staticmethod
 def IsPunctuation(*__args):
  """
  IsPunctuation(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a punctuation mark.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a punctuation mark; otherwise,false.

  IsPunctuation(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a punctuation mark.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a punctuation mark; otherwise,false.
  """
  pass
 @staticmethod
 def IsSeparator(*__args):
  """
  IsSeparator(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a separator character.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a separator character; otherwise,false.

  IsSeparator(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a separator character.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a separator character; otherwise,false.
  """
  pass
 @staticmethod
 def IsSurrogate(*__args):
  """
  IsSurrogate(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string has a surrogate 

    code unit.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a either a high surrogate or a low surrogate; 

    otherwise,false.

  

  IsSurrogate(c: Char) -> bool

  

   Indicates whether the specified character has a surrogate code unit.

  

   c: The Unicode character to evaluate.

   Returns: true if c is either a high surrogate or a low surrogate; otherwise,false.
  """
  pass
 @staticmethod
 def IsSurrogatePair(*__args):
  """
  IsSurrogatePair(highSurrogate: Char,lowSurrogate: Char) -> bool

  

   Indicates whether the two specified System.Char objects form a surrogate pair.

  

   highSurrogate: The character to evaluate as the high surrogate of a surrogate pair.

   lowSurrogate: The character to evaluate as the low surrogate of a surrogate pair.

   Returns: true if the numeric value of the highSurrogate parameter ranges from U+D800 through U+DBFF,and 

    the numeric value of the lowSurrogate parameter ranges from U+DC00 through U+DFFF; otherwise,

    false.

  

  IsSurrogatePair(s: str,index: int) -> bool

  

   Indicates whether two adjacent System.Char objects at a specified position in a string form a 

    surrogate pair.

  

  

   s: A string.

   index: The starting position of the pair of characters to evaluate within s.

   Returns: true if the s parameter includes adjacent characters at positions index and index + 1,and the 

    numeric value of the character at position index ranges from U+D800 through U+DBFF,and the 

    numeric value of the character at position index+1 ranges from U+DC00 through U+DFFF; otherwise,

    false.
  """
  pass
 @staticmethod
 def IsSymbol(*__args):
  """
  IsSymbol(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as a symbol character.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is a symbol character; otherwise,false.

  IsSymbol(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as a symbol character.

  

   c: The Unicode character to evaluate.

   Returns: true if c is a symbol character; otherwise,false.
  """
  pass
 @staticmethod
 def IsUpper(*__args):
  """
  IsUpper(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as an uppercase letter.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is an uppercase letter; otherwise,false.

  IsUpper(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as an uppercase letter.

  

   c: The Unicode character to evaluate.

   Returns: true if c is an uppercase letter; otherwise,false.
  """
  pass
 @staticmethod
 def IsWhiteSpace(*__args):
  """
  IsWhiteSpace(s: str,index: int) -> bool

  

   Indicates whether the character at the specified position in a specified string is categorized 

    as white space.

  

  

   s: A string.

   index: The position of the character to evaluate in s.

   Returns: true if the character at position index in s is white space; otherwise,false.

  IsWhiteSpace(c: Char) -> bool

  

   Indicates whether the specified Unicode character is categorized as white space.

  

   c: The Unicode character to evaluate.

   Returns: true if c is white space; otherwise,false.
  """
  pass
 @staticmethod
 def Parse(s):
  """
  Parse(s: str) -> Char

  

   Converts the value of the specified string to its equivalent Unicode character.

  

   s: A string that contains a single character,or null.

   Returns: A Unicode character equivalent to the sole character in s.
  """
  pass
 @staticmethod
 def ToLower(c,culture=None):
  """
  ToLower(c: Char) -> Char

  

   Converts the value of a Unicode character to its lowercase equivalent.

  

   c: The Unicode character to convert.

   Returns: The lowercase equivalent of c,or the unchanged value of c,if c is already lowercase or not 

    alphabetic.

  

  ToLower(c: Char,culture: CultureInfo) -> Char

  

   Converts the value of a specified Unicode character to its lowercase equivalent using specified 

    culture-specific formatting information.

  

  

   c: The Unicode character to convert.

   culture: An object that supplies culture-specific casing rules.

   Returns: The lowercase equivalent of c,modified according to culture,or the unchanged value of c,if c 

    is already lowercase or not alphabetic.
  """
  pass
 @staticmethod
 def ToLowerInvariant(c):
  """
  ToLowerInvariant(c: Char) -> Char

  

   Converts the value of a Unicode character to its lowercase equivalent using the casing rules of 

    the invariant culture.

  

  

   c: The Unicode character to convert.

   Returns: The lowercase equivalent of the c parameter,or the unchanged value of c,if c is already 

    lowercase or not alphabetic.
  """
  pass
 def ToString(self,*__args):
  """
  ToString(c: Char) -> str

  

   Converts the specified Unicode character to its equivalent string representation.

  

   c: The Unicode character to convert.

   Returns: The string representation of the value of c.

  ToString(self: Char,provider: IFormatProvider) -> str

  

   Converts the value of this instance to its equivalent string representation using the specified 

    culture-specific format information.

  

  

   provider: (Reserved) An object that supplies culture-specific formatting information.

   Returns: The string representation of the value of this instance as specified by provider.

  ToString(self: Char) -> str

  

   Converts the value of this instance to its equivalent string representation.

   Returns: The string representation of the value of this instance.
  """
  pass
 @staticmethod
 def ToUpper(c,culture=None):
  """
  ToUpper(c: Char) -> Char

  

   Converts the value of a Unicode character to its uppercase equivalent.

  

   c: The Unicode character to convert.

   Returns: The uppercase equivalent of c,or the unchanged value of c if c is already uppercase,has no 

    uppercase equivalent,or is not alphabetic.

  

  ToUpper(c: Char,culture: CultureInfo) -> Char

  

   Converts the value of a specified Unicode character to its uppercase equivalent using specified 

    culture-specific formatting information.

  

  

   c: The Unicode character to convert.

   culture: An object that supplies culture-specific casing rules.

   Returns: The uppercase equivalent of c,modified according to culture,or the unchanged value of c if c 

    is already uppercase,has no uppercase equivalent,or is not alphabetic.
  """
  pass
 @staticmethod
 def ToUpperInvariant(c):
  """
  ToUpperInvariant(c: Char) -> Char

  

   Converts the value of a Unicode character to its uppercase equivalent using the casing rules of 

    the invariant culture.

  

  

   c: The Unicode character to convert.

   Returns: The uppercase equivalent of the c parameter,or the unchanged value of c,if c is already 

    uppercase or not alphabetic.
  """
  pass
 @staticmethod
 def TryParse(s,result):
  """
  TryParse(s: str) -> (bool,Char)

  

   Converts the value of the specified string to its equivalent Unicode character. A return code 

    indicates whether the conversion succeeded or failed.

  

  

   s: A string that contains a single character,or null.

   Returns: true if the s parameter was converted successfully; otherwise,false.
  """
  pass
 def __cmp__(self,*args):
  """ x.__cmp__(y) <==> cmp(x,y) """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: Char,other: str) -> bool

  __contains__(self: Char,other: Char) -> bool
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __hash__(self,*args):
  """ x.__hash__() <==> hash(x) """
  pass
 def __index__(self,*args):
  """ __index__(self: Char) -> int """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: Char) -> str """
  pass
 def __str__(self,*args):
  pass
 MaxValue=None
 MinValue=None




class ScrollBarRenderer(object):
 """ Provides methods used to render a scroll bar control with visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawArrowButton(g,bounds,state):
  """
  DrawArrowButton(g: Graphics,bounds: Rectangle,state: ScrollBarArrowButtonState)

   Draws a scroll arrow with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll arrow.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll arrow.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarArrowButtonState values that specifies the 

    visual state of the scroll arrow.
  """
  pass
 @staticmethod
 def DrawHorizontalThumb(g,bounds,state):
  """
  DrawHorizontalThumb(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a horizontal scroll box (also known as the thumb) with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll box.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll box.
  """
  pass
 @staticmethod
 def DrawHorizontalThumbGrip(g,bounds,state):
  """
  DrawHorizontalThumbGrip(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a grip on a horizontal scroll box (also known as the thumb) with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll box grip.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll box grip.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll box grip.
  """
  pass
 @staticmethod
 def DrawLeftHorizontalTrack(g,bounds,state):
  """
  DrawLeftHorizontalTrack(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a horizontal scroll bar track with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll bar track.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll bar track.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll bar track.
  """
  pass
 @staticmethod
 def DrawLowerVerticalTrack(g,bounds,state):
  """
  DrawLowerVerticalTrack(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a vertical scroll bar track with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll bar track.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll bar track.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll bar track.
  """
  pass
 @staticmethod
 def DrawRightHorizontalTrack(g,bounds,state):
  """
  DrawRightHorizontalTrack(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a horizontal scroll bar track with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll bar track.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll bar track.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll bar track.
  """
  pass
 @staticmethod
 def DrawSizeBox(g,bounds,state):
  """
  DrawSizeBox(g: Graphics,bounds: Rectangle,state: ScrollBarSizeBoxState)

   Draws a scroll bar sizing handle with visual styles.

  

   g: The System.Drawing.Graphics used to draw the sizing handle.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the sizing handle.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarSizeBoxState values that specifies the 

    visual state of the sizing handle.
  """
  pass
 @staticmethod
 def DrawUpperVerticalTrack(g,bounds,state):
  """
  DrawUpperVerticalTrack(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a vertical scroll bar track with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll bar track.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll bar track.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll bar track.
  """
  pass
 @staticmethod
 def DrawVerticalThumb(g,bounds,state):
  """
  DrawVerticalThumb(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a vertical scroll box (also known as the thumb) with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll box.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll box.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll box.
  """
  pass
 @staticmethod
 def DrawVerticalThumbGrip(g,bounds,state):
  """
  DrawVerticalThumbGrip(g: Graphics,bounds: Rectangle,state: ScrollBarState)

   Draws a grip on a vertical scroll box (also known as the thumb) with visual styles.

  

   g: The System.Drawing.Graphics used to draw the scroll box grip.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the scroll box grip.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll box grip.
  """
  pass
 @staticmethod
 def GetSizeBoxSize(g,state):
  """
  GetSizeBoxSize(g: Graphics,state: ScrollBarState) -> Size

  

   Returns the size of the sizing handle.

  

   g: The System.Drawing.Graphics this operation will use.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the sizing handle.

  

   Returns: A System.Drawing.Size that specifies the size of the sizing handle.
  """
  pass
 @staticmethod
 def GetThumbGripSize(g,state):
  """
  GetThumbGripSize(g: Graphics,state: ScrollBarState) -> Size

  

   Returns the size of the scroll box grip.

  

   g: The System.Drawing.Graphics this operation will use.

   state: One of the System.Windows.Forms.VisualStyles.ScrollBarState values that specifies the visual 

    state of the scroll box grip.

  

   Returns: A System.Drawing.Size that specifies the size of the scroll box grip.
  """
  pass
 IsSupported=True




class ImageFormatConverter(TypeConverter):
 """
 System.Drawing.ImageFormatConverter is a class that can be used to convert System.Drawing.Imaging.ImageFormat objects from one data type to another. Access this class through the System.ComponentModel.TypeDescriptor object.

 

 ImageFormatConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: ImageFormatConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Indicates whether this converter can convert an object in the specified source type to the 

    native type of the converter.

  

  

   context: A formatter context. This object can be used to get more information about the environment this 

    converter is being called from. This may be null,so you should always check. Also,properties 

    on the context object may also return null.

  

   sourceType: The type you want to convert from.

   Returns: This method returns true if this object can perform the conversion.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: ImageFormatConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Gets a value indicating whether this converter can convert an object to the specified 

    destination type using the context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that specifies the context for this type 

    conversion.

  

   destinationType: The System.Type that represents the type to which you want to convert this 

    System.Drawing.Imaging.ImageFormat object.

  

   Returns: This method returns true if this object can perform the conversion.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: ImageFormatConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the specified object to an System.Drawing.Imaging.ImageFormat object.

  

   context: A formatter context. This object can be used to get more information about the environment this 

    converter is being called from. This may be null,so you should always check. Also,properties 

    on the context object may also return null.

  

   culture: A System.Globalization.CultureInfo object that specifies formatting conventions for a particular 

    culture.

  

   value: The object to convert.

   Returns: The converted object.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ImageFormatConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the specified object to the specified type.

  

   context: A formatter context. This object can be used to get more information about the environment this 

    converter is being called from. This may be null,so you should always check. Also,properties 

    on the context object may also return null.

  

   culture: A System.Globalization.CultureInfo object that specifies formatting conventions for a particular 

    culture.

  

   value: The object to convert.

   destinationType: The type to convert the object to.

   Returns: The converted object.
  """
  pass
 def GetStandardValues(self,context=None):
  """
  GetStandardValues(self: ImageFormatConverter,context: ITypeDescriptorContext) -> StandardValuesCollection

  

   Gets a collection that contains a set of standard values for the data type this validator is 

    designed for. Returns null if the data type does not support a standard set of values.

  

  

   context: A formatter context. This object can be used to get more information about the environment this 

    converter is being called from. This may be null,so you should always check. Also,properties 

    on the context object may also return null.

  

   Returns: A collection that contains a standard set of valid values,or null. The default implementation 

    always returns null.
  """
  pass
 def GetStandardValuesSupported(self,context=None):
  """
  GetStandardValuesSupported(self: ImageFormatConverter,context: ITypeDescriptorContext) -> bool

  

   Indicates whether this object supports a standard set of values that can be picked from a list.

  

   context: A type descriptor through which additional context can be provided.

   Returns: This method returns true if the erload:System.Drawing.ImageFormatConverter.GetStandardValues 

    method should be called to find a common set of values the object supports.
  """
  pass



"""python engine compatibility module.

Examples:
    ```python
    from pyrevit.compat import IRONPY2711
    from pyrevit.compat import safe_strtype
    ```
"""

import sys
import System

PY2 = sys.version_info[0] == 2
PY3 = sys.version_info[0] == 3
IRONPY = '.net' in sys.version.lower()
IRONPY2 = PY2 and IRONPY
IRONPY3 = PY3 and IRONPY
NETCORE = System.Environment.Version.Major >= 8  # Revit 2025 onwards
NETFRAMEWORK = not NETCORE # Revit 2024 and earlier
NO_REVIT = -1
REVIT_NETCORE_VERSION = 2025

#pylint: disable=import-error,unused-import
if PY3:
    __builtins__["unicode"] = str

if PY2:
    import _winreg as winreg
    import ConfigParser as configparser
    from collections import Iterable, Callable
    import urllib2
    from urlparse import urlparse

elif PY3:
    import winreg as winreg
    import configparser as configparser
    from collections.abc import Iterable, Callable
    import urllib
    from urllib.parse import urlparse


def _get_revit_version():
    """Returns the current Revit version as an integer."""
    if __revit__ is None:
        return NO_REVIT
    try:
        # UIApplication
        return int(__revit__.Application.VersionNumber)
    except AttributeError:
        pass
    try:
        # Application, (ControlledApplication)
        return int(__revit__.VersionNumber)
    except AttributeError:
        # ControlledApplication
        return int(__revit__.ControlledApplication.VersionNumber)


#pylint: disable=C0103
safe_strtype = str
if PY2:
    # https://gist.github.com/gornostal/1f123aaf838506038710
    safe_strtype = lambda x: unicode(x)  #pylint: disable=E0602,unnecessary-lambda


def get_elementid_value_func():
    """Returns the ElementId value extraction function based on the Revit version.

    Follows API changes in Revit 2024.

    Returns:
        function: A function returns the value of an ElementId.

    Examples:
        ```python
        get_elementid_value = get_elementid_value_func()
        sheet_revids = {get_elementid_value(x) for x in self.revit_sheet.GetAllRevisionIds()}
        add_sheet_revids = {get_elementid_value(x) for x in self.revit_sheet.GetAdditionalRevisionIds()}
        ```
    """
    attr = "Value" if _get_revit_version() > 2023 else "IntegerValue"
    def from_elementid(item):
        return getattr(item, attr)
    return from_elementid


def get_elementid_from_value_func():
    """Returns the ElementId constructor function based on the Revit version.

    Follows API changes in Revit 2024.

    Returns:
        function: A function that takes a numeric value and returns an ElementId.

    Example:
        ```python
        get_elementid_from_value = get_elementid_from_value_func()
        element_id = get_elementid_from_value(123456)
        ```
    """
    from pyrevit.api import DB
    cast_class = System.Int64 if _get_revit_version() > 2023 else int
    def from_value(value):
        return DB.ElementId(cast_class(value))
    return from_value


def urlopen(url):
    """Urlopen wrapper.

    Args:
        url (str): request url
    """
    if PY3:
        return urllib.request.urlopen(url)
    return urllib2.urlopen(url)


def make_request(url, headers, data):
    """Urlopen wrapper to create and send a request.

    Args:
        url (str): request url
        headers (dict[str, str]): headers
        data (bytes | None): request data
    """
    if PY3:
        req = urllib.request.Request(url, headers, data)
        urllib.request.urlopen(req).close()
        return

    req = urllib2.Request(url, headers, data)
    urllib2.urlopen(req).close()



class EventLogTraceListener(TraceListener,IDisposable):
 """
 Provides a simple listener that directs tracing or debugging output to an System.Diagnostics.EventLog.

 

 EventLogTraceListener()

 EventLogTraceListener(eventLog: EventLog)

 EventLogTraceListener(source: str)
 """
 def Close(self):
  """
  Close(self: EventLogTraceListener)

   Closes the event log so that it no longer receives tracing or debugging output.
  """
  pass
 def Dispose(self):
  """ Dispose(self: EventLogTraceListener,disposing: bool) """
  pass
 def GetSupportedAttributes(self,*args):
  """
  GetSupportedAttributes(self: TraceListener) -> Array[str]

  

   Gets the custom attributes supported by the trace listener.

   Returns: A string array naming the custom attributes supported by the trace listener,or null if there 

    are no custom attributes.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def TraceData(self,eventCache,source,severity,id,data):
  """
  TraceData(self: EventLogTraceListener,eventCache: TraceEventCache,source: str,severity: TraceEventType,id: int,*data: Array[object])

   Writes trace information,an array of data objects,and event information to the event log.

  

   eventCache: An object that contains the current process ID,thread ID,and stack trace information.

   source: A name used to identify the output; typically the name of the application that generated the 

    trace event.

  

   severity: One of the enumeration values that specifies the type of event that has caused the trace.

   id: A numeric identifier for the event. The combination of source and id uniquely identifies an 

    event.

  

   data: An array of data objects.

  TraceData(self: EventLogTraceListener,eventCache: TraceEventCache,source: str,severity: TraceEventType,id: int,data: object)

   Writes trace information,a data object,and event information to the event log.

  

   eventCache: An object that contains the current process ID,thread ID,and stack trace information.

   source: A name used to identify the output; typically the name of the application that generated the 

    trace event.

  

   severity: One of the enumeration values that specifies the type of event that has caused the trace.

   id: A numeric identifier for the event. The combination of source and id uniquely identifies an 

    event.

  

   data: A data object to write to the output file or stream.
  """
  pass
 def TraceEvent(self,eventCache,source,*__args):
  """
  TraceEvent(self: EventLogTraceListener,eventCache: TraceEventCache,source: str,severity: TraceEventType,id: int,message: str)

   Writes trace information,a message,and event information to the event log.

  

   eventCache: An object that contains the current process ID,thread ID,and stack trace information.

   source: A name used to identify the output; typically the name of the application that generated the 

    trace event.

  

   severity: One of the enumeration values that specifies the type of event that has caused the trace.

   id: A numeric identifier for the event. The combination of source and id uniquely identifies an 

    event.

  

   message: The trace message.

  TraceEvent(self: EventLogTraceListener,eventCache: TraceEventCache,source: str,severity: TraceEventType,id: int,format: str,*args: Array[object])

   Writes trace information,a formatted array of objects,and event information to the event log.

  

   eventCache: An object that contains the current process ID,thread ID,and stack trace information.

   source: A name used to identify the output; typically the name of the application that generated the 

    trace event.

  

   severity: One of the enumeration values that specifies the type of event that has caused the trace.

   id: A numeric identifier for the event. The combination of source and id uniquely identifies an 

    event.

  

   format: A format string that contains zero or more format items that correspond to objects in the args 

    array.

  

   args: An object array containing zero or more objects to format.
  """
  pass
 def Write(self,*__args):
  """
  Write(self: EventLogTraceListener,message: str)

   Writes a message to the event log for this instance.

  

   message: The message to write.
  """
  pass
 def WriteIndent(self,*args):
  """
  WriteIndent(self: TraceListener)

   Writes the indent to the listener you create when you implement this class,and resets the 

    System.Diagnostics.TraceListener.NeedIndent property to false.
  """
  pass
 def WriteLine(self,*__args):
  """
  WriteLine(self: EventLogTraceListener,message: str)

   Writes a message to the event log for this instance.

  

   message: The message to write.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,eventLog: EventLog)

  __new__(cls: type,source: str)
  """
  pass
 EventLog=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the event log to write to.



Get: EventLog(self: EventLogTraceListener) -> EventLog



Set: EventLog(self: EventLogTraceListener)=value

"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of this System.Diagnostics.EventLogTraceListener.



Get: Name(self: EventLogTraceListener) -> str



Set: Name(self: EventLogTraceListener)=value

"""

 NeedIndent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether to indent the output.



"""





class ScrollProperties(object):
 """ Encapsulates properties related to scrolling. """
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """ __new__(cls: type,container: ScrollableControl) """
  pass
 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the scroll bar can be used on the container.



Get: Enabled(self: ScrollProperties) -> bool



Set: Enabled(self: ScrollProperties)=value

"""

 LargeChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the distance to move a scroll bar in response to a large scroll command.



Get: LargeChange(self: ScrollProperties) -> int



Set: LargeChange(self: ScrollProperties)=value

"""

 Maximum=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the upper limit of the scrollable range.



Get: Maximum(self: ScrollProperties) -> int



Set: Maximum(self: ScrollProperties)=value

"""

 Minimum=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the lower limit of the scrollable range.



Get: Minimum(self: ScrollProperties) -> int



Set: Minimum(self: ScrollProperties)=value

"""

 ParentControl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the control to which this scroll information applies.



"""

 SmallChange=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the distance to move a scroll bar in response to a small scroll command.



Get: SmallChange(self: ScrollProperties) -> int



Set: SmallChange(self: ScrollProperties)=value

"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a numeric value that represents the current position of the scroll bar box.



Get: Value(self: ScrollProperties) -> int



Set: Value(self: ScrollProperties)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the scroll bar can be seen by the user.



Get: Visible(self: ScrollProperties) -> bool



Set: Visible(self: ScrollProperties)=value

"""





class RuntimeEnvironment(object):
 """
 Provides a collection of static methods that return information about the common language runtime environment.

 

 RuntimeEnvironment()
 """
 @staticmethod
 def FromGlobalAccessCache(a):
  """
  FromGlobalAccessCache(a: Assembly) -> bool

  

   Tests whether the specified assembly is loaded in the global assembly cache.

  

   a: The assembly to test.

   Returns: true if the assembly is loaded in the global assembly cache; otherwise,false.
  """
  pass
 @staticmethod
 def GetRuntimeDirectory():
  """
  GetRuntimeDirectory() -> str

  

   Returns the directory where the common language runtime is installed.

   Returns: A string that contains the path to the directory where the common language runtime is installed.
  """
  pass
 @staticmethod
 def GetRuntimeInterfaceAsIntPtr(clsid,riid):
  """
  GetRuntimeInterfaceAsIntPtr(clsid: Guid,riid: Guid) -> IntPtr

  

   Returns the specified interface on the specified class.

  

   clsid: The identifier for the desired class.

   riid: The identifier for the desired interface.

   Returns: An unmanaged pointer to the requested interface.
  """
  pass
 @staticmethod
 def GetRuntimeInterfaceAsObject(clsid,riid):
  """
  GetRuntimeInterfaceAsObject(clsid: Guid,riid: Guid) -> object

  

   Returns an instance of a type that represents a COM object by a pointer to its IUnknown 

    interface.

  

  

   clsid: The identifier for the desired class.

   riid: The identifier for the desired interface.

   Returns: An object that represents the specified unmanaged COM object.
  """
  pass
 @staticmethod
 def GetSystemVersion():
  """
  GetSystemVersion() -> str

  

   Gets the version number of the common language runtime that is running the current process.

   Returns: A string containing the version number of the common language runtime.
  """
  pass
 SystemConfigurationFile='C:\\Windows\\Microsoft.NET\\Framework\\v4.0.30319\\config\\machine.config'




class TypeIdentifierAttribute(Attribute,_Attribute):
 """
 Provides support for type equivalence.

 

 TypeIdentifierAttribute()

 TypeIdentifierAttribute(scope: str,identifier: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,scope=None,identifier=None):
  """
  __new__(cls: type)

  __new__(cls: type,scope: str,identifier: str)
  """
  pass
 Identifier=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the identifier parameter that was passed to the System.Runtime.InteropServices.TypeIdentifierAttribute.#ctor(System.String,System.String) constructor.



Get: Identifier(self: TypeIdentifierAttribute) -> str



"""

 Scope=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the value of the scope parameter that was passed to the System.Runtime.InteropServices.TypeIdentifierAttribute.#ctor(System.String,System.String) constructor.



Get: Scope(self: TypeIdentifierAttribute) -> str



"""





"""
Rhino - Rhino3dmIO

Rhino3dmIO is a subset of RhinoCommon and it gives you access to openNurbs,
allowing you to, amongst other things, read and write 3dm files.

Usage:

    >>> from rpw.extras.rhino import Rhino as rc
    >>> pt1 = rc.Geometry.Point3d(0,0,0)
    >>> pt2 = rc.Geometry.Point3d(10,10,0)
    >>> line1 = rc.Geometry.Line(pt1, pt2)
    >>> line1.Length
    14.142135623730951
    >>>
    >>> pt1 = rc.Geometry.Point3d(10,0,0)
    >>> pt2 = rc.Geometry.Point3d(0,10,0)
    >>> line2 = rc.Geometry.Line(pt1, pt2)
    >>>
    >>> rc.Geometry.Intersect.Intersection.LineLine(line1, line2)
    (True, 0.5, 0.5)
    >>>
    >>> file3dm = f = rc.FileIO.File3dm()
    >>> file3md_options = rc.FileIO.File3dmWriteOptions()
    >>> file3dm.Objects.AddLine(line1)
    >>> filepath = 'c:/folder/test.3dm'
    >>> file3dm.Write(filepath, file3md_options)

.. note::
    Although the openNURBS toolkit appears to be a full-featured geometry
    library, it is not.     The toolkit does not include a
    number of important features, including:

    *   Closest point calculations
    *   Intersection calculations
    *   Surface tessellation (meshing)
    *   Interpolation
    *   Booleans
    *   Area and mass property calculations
    *   Other miscellaneous geometry calculations

    [ Note from McNeel's website on openNURBS ]


More Information about openNURBES in the links below:
    * `Github Repo <https://github.com/mcneel/rhinocommon/tree/rhino3dmio>`_
    * `RhinoCommon API <http://developer.rhino3d.com/api/>`_
    * `openNURBS <http://developer.rhino3d.com/guides/opennurbs/what-is-opennurbs/>`_

"""
from rpw.utils.dotnet import clr
clr.AddReference('Rhino3dmIO')

import Rhino



class ProfessionalColors(object):
 """ Provides System.Drawing.Color structures that are colors of a Windows display element. This class cannot be inherited. """
 ButtonCheckedGradientBegin=None
 ButtonCheckedGradientEnd=None
 ButtonCheckedGradientMiddle=None
 ButtonCheckedHighlight=None
 ButtonCheckedHighlightBorder=None
 ButtonPressedBorder=None
 ButtonPressedGradientBegin=None
 ButtonPressedGradientEnd=None
 ButtonPressedGradientMiddle=None
 ButtonPressedHighlight=None
 ButtonPressedHighlightBorder=None
 ButtonSelectedBorder=None
 ButtonSelectedGradientBegin=None
 ButtonSelectedGradientEnd=None
 ButtonSelectedGradientMiddle=None
 ButtonSelectedHighlight=None
 ButtonSelectedHighlightBorder=None
 CheckBackground=None
 CheckPressedBackground=None
 CheckSelectedBackground=None
 GripDark=None
 GripLight=None
 ImageMarginGradientBegin=None
 ImageMarginGradientEnd=None
 ImageMarginGradientMiddle=None
 ImageMarginRevealedGradientBegin=None
 ImageMarginRevealedGradientEnd=None
 ImageMarginRevealedGradientMiddle=None
 MenuBorder=None
 MenuItemBorder=None
 MenuItemPressedGradientBegin=None
 MenuItemPressedGradientEnd=None
 MenuItemPressedGradientMiddle=None
 MenuItemSelected=None
 MenuItemSelectedGradientBegin=None
 MenuItemSelectedGradientEnd=None
 MenuStripGradientBegin=None
 MenuStripGradientEnd=None
 OverflowButtonGradientBegin=None
 OverflowButtonGradientEnd=None
 OverflowButtonGradientMiddle=None
 RaftingContainerGradientBegin=None
 RaftingContainerGradientEnd=None
 SeparatorDark=None
 SeparatorLight=None
 StatusStripGradientBegin=None
 StatusStripGradientEnd=None
 ToolStripBorder=None
 ToolStripContentPanelGradientBegin=None
 ToolStripContentPanelGradientEnd=None
 ToolStripDropDownBackground=None
 ToolStripGradientBegin=None
 ToolStripGradientEnd=None
 ToolStripGradientMiddle=None
 ToolStripPanelGradientBegin=None
 ToolStripPanelGradientEnd=None




class SwitchLevelAttribute(Attribute,_Attribute):
 """
 Identifies the level type for a switch.

 

 SwitchLevelAttribute(switchLevelType: Type)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,switchLevelType):
  """ __new__(cls: type,switchLevelType: Type) """
  pass
 SwitchLevelType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type that determines whether a trace should be written.



Get: SwitchLevelType(self: SwitchLevelAttribute) -> Type



Set: SwitchLevelType(self: SwitchLevelAttribute)=value

"""





class DataGridViewColumnCollection(BaseCollection,ICollection,IEnumerable,IList):
 """
 Represents a collection of System.Windows.Forms.DataGridViewColumn objects in a System.Windows.Forms.DataGridView control.

 

 DataGridViewColumnCollection(dataGridView: DataGridView)
 """
 def Add(self,*__args):
  """
  Add(self: DataGridViewColumnCollection,dataGridViewColumn: DataGridViewColumn) -> int

  

   Adds the given column to the collection.

  

   dataGridViewColumn: The System.Windows.Forms.DataGridViewColumn to add.

   Returns: The index of the column.

  Add(self: DataGridViewColumnCollection,columnName: str,headerText: str) -> int

  

   Adds a System.Windows.Forms.DataGridViewTextBoxColumn with the given column name and column 

    header text to the collection.

  

  

   columnName: The name by which the column will be referred.

   headerText: The text for the column's header.

   Returns: The index of the column.
  """
  pass
 def AddRange(self,dataGridViewColumns):
  """
  AddRange(self: DataGridViewColumnCollection,*dataGridViewColumns: Array[DataGridViewColumn])

   Adds a range of columns to the collection.

  

   dataGridViewColumns: An array of System.Windows.Forms.DataGridViewColumn objects to add.
  """
  pass
 def Clear(self):
  """
  Clear(self: DataGridViewColumnCollection)

   Clears the collection.
  """
  pass
 def Contains(self,*__args):
  """
  Contains(self: DataGridViewColumnCollection,columnName: str) -> bool

  

   Determines whether the collection contains the column referred to by the given name.

  

   columnName: The name of the column to look for.

   Returns: true if the column is contained in the collection; otherwise,false.

  Contains(self: DataGridViewColumnCollection,dataGridViewColumn: DataGridViewColumn) -> bool

  

   Determines whether the collection contains the given column.

  

   dataGridViewColumn: The System.Windows.Forms.DataGridViewColumn to look for.

   Returns: true if the given column is in the collection; otherwise,false.
  """
  pass
 def CopyTo(self,*__args):
  """
  CopyTo(self: DataGridViewColumnCollection,array: Array[DataGridViewColumn],index: int)

   Copies the items from the collection to the given array.

  

   array: The destination System.Windows.Forms.DataGridViewColumn array.

   index: The index of the destination array at which to start copying.
  """
  pass
 def GetColumnCount(self,includeFilter):
  """
  GetColumnCount(self: DataGridViewColumnCollection,includeFilter: DataGridViewElementStates) -> int

  

   Returns the number of columns that meet the given filter requirements.

  

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter for inclusion.

  

   Returns: The number of columns that meet the filter requirements.
  """
  pass
 def GetColumnsWidth(self,includeFilter):
  """
  GetColumnsWidth(self: DataGridViewColumnCollection,includeFilter: DataGridViewElementStates) -> int

  

   Returns the width,in pixels,required to display all of the columns that meet the given filter 

    requirements.

  

  

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter for inclusion.

  

   Returns: The width,in pixels,that is necessary to display all of the columns that meet the filter 

    requirements.
  """
  pass
 def GetFirstColumn(self,includeFilter,excludeFilter=None):
  """
  GetFirstColumn(self: DataGridViewColumnCollection,includeFilter: DataGridViewElementStates,excludeFilter: DataGridViewElementStates) -> DataGridViewColumn

  

   Returns the first column in display order that meets the given inclusion-filter and 

    exclusion-filter requirements.

  

  

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for inclusion.

  

   excludeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for exclusion.

  

   Returns: The first column in display order that meets the given filter requirements,or null if no column 

    is found.

  

  GetFirstColumn(self: DataGridViewColumnCollection,includeFilter: DataGridViewElementStates) -> DataGridViewColumn

  

   Returns the first column in display order that meets the given inclusion-filter requirements.

  

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represents the filter for inclusion.

  

   Returns: The first column in display order that meets the given filter requirements,or null if no column 

    is found.
  """
  pass
 def GetLastColumn(self,includeFilter,excludeFilter):
  """
  GetLastColumn(self: DataGridViewColumnCollection,includeFilter: DataGridViewElementStates,excludeFilter: DataGridViewElementStates) -> DataGridViewColumn

  

   Returns the last column in display order that meets the given filter requirements.

  

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for inclusion.

  

   excludeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for exclusion.

  

   Returns: The last displayed column in display order that meets the given filter requirements,or null if 

    no column is found.
  """
  pass
 def GetNextColumn(self,dataGridViewColumnStart,includeFilter,excludeFilter):
  """
  GetNextColumn(self: DataGridViewColumnCollection,dataGridViewColumnStart: DataGridViewColumn,includeFilter: DataGridViewElementStates,excludeFilter: DataGridViewElementStates) -> DataGridViewColumn

  

   Gets the first column after the given column in display order that meets the given filter 

    requirements.

  

  

   dataGridViewColumnStart: The column from which to start searching for the next column.

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for inclusion.

  

   excludeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for exclusion.

  

   Returns: The next column that meets the given filter requirements,or null if no column is found.
  """
  pass
 def GetPreviousColumn(self,dataGridViewColumnStart,includeFilter,excludeFilter):
  """
  GetPreviousColumn(self: DataGridViewColumnCollection,dataGridViewColumnStart: DataGridViewColumn,includeFilter: DataGridViewElementStates,excludeFilter: DataGridViewElementStates) -> DataGridViewColumn

  

   Gets the last column prior to the given column in display order that meets the given filter 

    requirements.

  

  

   dataGridViewColumnStart: The column from which to start searching for the previous column.

   includeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for inclusion.

  

   excludeFilter: A bitwise combination of the System.Windows.Forms.DataGridViewElementStates values that 

    represent the filter to apply for exclusion.

  

   Returns: The previous column that meets the given filter requirements,or null if no column is found.
  """
  pass
 def IndexOf(self,dataGridViewColumn):
  """
  IndexOf(self: DataGridViewColumnCollection,dataGridViewColumn: DataGridViewColumn) -> int

  

   Gets the index of the given System.Windows.Forms.DataGridViewColumn in the collection.

  

   dataGridViewColumn: The System.Windows.Forms.DataGridViewColumn to return the index of.

   Returns: The index of the given System.Windows.Forms.DataGridViewColumn.
  """
  pass
 def Insert(self,columnIndex,dataGridViewColumn):
  """
  Insert(self: DataGridViewColumnCollection,columnIndex: int,dataGridViewColumn: DataGridViewColumn)

   Inserts a column at the given index in the collection.

  

   columnIndex: The zero-based index at which to insert the given column.

   dataGridViewColumn: The System.Windows.Forms.DataGridViewColumn to insert.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: DataGridViewColumnCollection,e: CollectionChangeEventArgs)

   Raises the System.Windows.Forms.DataGridViewColumnCollection.CollectionChanged event.

  

   e: A System.ComponentModel.CollectionChangeEventArgs that contains the event data.
  """
  pass
 def Remove(self,*__args):
  """
  Remove(self: DataGridViewColumnCollection,columnName: str)

   Removes the column with the specified name from the collection.

  

   columnName: The name of the column to delete.

  Remove(self: DataGridViewColumnCollection,dataGridViewColumn: DataGridViewColumn)

   Removes the specified column from the collection.

  

   dataGridViewColumn: The column to delete.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: DataGridViewColumnCollection,index: int)

   Removes the column at the given index in the collection.

  

   index: The index of the column to delete.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 @staticmethod
 def __new__(self,dataGridView):
  """ __new__(cls: type,dataGridView: DataGridView) """
  pass
 DataGridView=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.DataGridView upon which the collection performs column-related operations.



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)


 CollectionChanged=None

